<?php return array(
    'root' => array(
        'name' => 'vpn/portal',
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'reference' => NULL,
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'fkooman/oauth2-server' => array(
            'pretty_version' => '8.0.0',
            'version' => '8.0.0.0',
            'reference' => 'a4179e671d2cef85bde68d9ce8e9d10dcc9d8446',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fkooman/oauth2-server',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fkooman/radius' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => '11d52b86b41078fe747872680a424af3c6040fdb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fkooman/radius',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fkooman/secookie' => array(
            'pretty_version' => '6.2.0',
            'version' => '6.2.0.0',
            'reference' => 'd1d5672f1a9aaad8e2d018ce892da6f6351ade54',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fkooman/secookie',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'vpn/portal' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'reference' => NULL,
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
