<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '',
    '#Unique Guest Users' => '',
    '#Unique Users' => '',
    '#Unique users and max #connections per day' => '',
    'ACL Permission List' => '',
    'Account' => '',
    'Active' => '',
    'Active Configurations' => '',
    'Additional Credential' => '',
    'Aggregated' => '',
    'All' => '',
    'An application attempts to establish a VPN connection.' => '',
    'An error occurred.' => '',
    'Application Usage' => '',
    'Approve' => '',
    'Approve Application' => '',
    'Authentication Data' => '',
    'Authorized Applications' => '',
    'Authorized On' => '',
    'Available Profiles' => '',
    'Block LAN' => '',
    'CA' => '',
    'CPU Usage:' => '',
    'Change Password' => '',
    'Configurations' => '',
    'Confirm' => '',
    'Connected' => '',
    'Connections' => '',
    'Created On' => '',
    'Current Password' => '',
    'Current Password not correct!' => '',
    'Currently there are no clients connected to this profile.' => '',
    'DNS Search Domain(s)' => '',
    'DNS Server(s)' => '',
    'Danger Zone' => '',
    'Database' => '',
    'Date/Time' => '',
    'Default Gateway' => '',
    'Delete' => '',
    'Delete Account' => '',
    'Delete Account Data' => '',
    'Disable Account' => '',
    'Disabled' => '',
    'Disconnected' => '',
    'Distribution of unique users over the VPN applications.' => '',
    'Download' => '',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => '',
    'Driver' => '',
    'Enable Account' => '',
    'Error' => '',
    'Excluded Route(s)' => '',
    'Expires On' => '',
    'Export (CSV)' => '',
    'Extend' => '',
    'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => '',
    'Fingerprint' => '',
    'Here you can change the password for your account.' => '',
    'Home' => '',
    'Hostname' => '',
    'IP Address' => '',
    'IPs' => '',
    'IPv4 Prefix' => '',
    'IPv6 Prefix' => '',
    'Import or copy/paste this configuration to your WireGuard application.' => '',
    'Info' => '',
    'Issues' => '',
    'Keepalive' => '',
    'Last Used' => '',
    'Live' => '',
    'Log' => '',
    'MTU' => '',
    'Maintenance' => '',
    'Max #Connections' => '',
    'More' => '',
    'N/A' => '',
    'Name' => '',
    'New Configuration' => '',
    'New Password' => '',
    'New Password (confirm)' => '',
    'New Password and New Password (confirm) MUST match!' => '',
    'No Permission(s)' => '',
    'No VPN profiles are available for your account.' => '',
    'Node URL' => '',
    'Node(s)' => '',
    'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => '',
    'Offered Ports' => '',
    'Offline' => '',
    'Online' => '',
    'Only approve this when you are trying to establish a VPN connection with this application!' => '',
    'OpenVPN' => '',
    'OpenVPN (Prefer TCP)' => '',
    'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => '',
    'Password' => '',
    'Permissions' => '',
    'Please sign in with your username and password.' => '',
    'Port' => '',
    'Ports' => '',
    'Preferred Protocol' => '',
    'Profile' => '',
    'Profile ID' => '',
    'Profile Usage' => '',
    'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => '',
    'Proxy URL' => '',
    'Public Key' => '',
    'Refresh' => '',
    'Results' => '',
    'Revoke' => '',
    'Route(s)' => '',
    'Search' => '',
    'Select a profile and choose a name, e.g. "Phone".' => '',
    'Server' => '',
    'Sign In' => '',
    'Sign Out' => '',
    'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => '',
    'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '',
    'The credentials you provided were not correct.' => '',
    'The list of applications you authorized to create a VPN connection.' => '',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => '',
    'The most recent VPN connections with this account.' => '',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => '',
    'The table below shows the per profile VPN usage over the last week.' => '',
    'There are no results matching your criteria.' => '',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => '',
    'This user does not have any active configurations.' => '',
    'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => '',
    'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => '',
    'Transport Protocol(s)' => '',
    'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => '',
    'User ID' => '',
    'Username' => '',
    'Users' => '',
    'VPN Portal' => '',
    'Version' => '',
    'Welcome to this VPN service!' => '',
    'Why is this necessary?' => '',
    'WireGuard' => '',
    'WireGuard (TCP)' => '',
    'WireGuard (UDP)' => '',
    'WireGuard Configuration' => '',
    'You can download the detailed VPN usage statistics below.' => '',
    'You cannot manage your own user account.' => '',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => '',
    'Your account does not have access to any VPN profile.' => '',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => '',
];
