<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => 'Кількість поточних (Максимально можливих) з’єднань',
    '#Connections in 5 minute intervals' => '#З’єднання з інтервалом у 5 хвилин',
    '#Unique Guest Users' => 'Кількість гостевих користувачяив',
    '#Unique Users' => 'Кількість унікальних користувачив',
    '#Unique users and max #connections per day' => '#Унікальні користувачі та максимальна кількість #з’єднань за день',
    'ACL Permission List' => 'Список дозволів ACL',
    'Account' => 'Акаунт',
    'Active' => 'Активний',
    'Active Configurations' => 'Активні конфігурації',
    //'Additional Credential' => '',
    'Aggregated' => 'Об’єднаний',
    'All' => 'Всі',
    'An application attempts to establish a VPN connection.' => 'Програма намагається встановити VPN-з’єднання.',
    'An error occurred.' => 'Сталася помилка.',
    'Application Usage' => 'Використання додатку',
    'Approve' => 'Підтвердити',
    'Approve Application' => 'Підтвердити додаток',
    'Authentication Data' => 'Автентифікаційні данні',
    'Authorized Applications' => 'Авторизовати додаток',
    'Authorized On' => 'Авторизований на',
    'Available Profiles' => 'Доступні профілі',
    'Block LAN' => 'Блокувати LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Використання CPU',
    'Change Password' => 'Змінити пароль',
    'Configurations' => 'Конфігурації',
    'Confirm' => 'Підтвердити',
    'Connected' => 'Підключено',
    'Connections' => 'Підключення',
    'Created On' => 'Створений на',
    'Current Password' => 'Актуальний пароль',
    'Current Password not correct!' => 'Актуальний пароль не коректний!',
    'Currently there are no clients connected to this profile.' => 'Наразі немає клієнтів, підключених до цього профілю.',
    'DNS Search Domain(s)' => 'DNS Пошук домена (ів)',
    'DNS Server(s)' => 'DNS сервер (и)',
    'Danger Zone' => 'Небезпечна зона',
    //'Database' => '',
    'Date/Time' => 'Дата/Час',
    'Default Gateway' => 'Основний шлюз',
    'Delete' => 'Видалити',
    'Delete Account' => 'Видалити обліковий запис',
    'Delete Account Data' => 'Видалити дані облікового запису',
    'Disable Account' => 'Вимкнути обліковий запис',
    'Disabled' => 'Вимкнено',
    'Disconnected' => 'Роз’єднано',
    'Distribution of unique users over the VPN applications.' => 'Розподіл унікальних користувачів через додатки VPN',
    'Download' => 'Завантажити',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Завантаження конфігурацій VPN заборонено. Будь ласка, використовуйте програму VPN.',
    //'Driver' => '',
    'Enable Account' => 'Увімкнути обліковий запис',
    'Error' => 'Помилка',
    'Excluded Route(s)' => 'Виключений маршрут (и)',
    'Expires On' => 'Термін дії закінчується',
    'Export (CSV)' => 'Експорт (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Знайти ідентифікатор користувача який використовує IPv4 або IPv6 адресу в конкретний проміжок часу.',
    'Fingerprint' => 'Відбиток',
    'Here you can change the password for your account.' => 'Тут ви можете змінити пароль для вашого акаунта.',
    'Home' => 'Додому',
    'Hostname' => 'Ім’я вузла (хоста)',
    'IP Address' => 'IP Адреса',
    'IPs' => 'IP-адреси',
    'IPv4 Prefix' => 'IPv4 префікс',
    'IPv6 Prefix' => 'IPv6 префікс',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Імпортуйте або скопіюйте/вставте цю конфігурацію до програми WireGuard',
    'Info' => 'Інформація',
    'Issues' => 'Проблеми',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Діячий',
    'Log' => 'Журнал',
    'MTU' => 'MTU',
    //'Maintenance' => '',
    'Max #Connections' => 'Максимальна кількість #З’єднань',
    'More' => 'Більше',
    'N/A' => 'N/A',
    'Name' => 'Ім’я',
    'New Configuration' => 'Нова конфігурація',
    'New Password' => 'Новий пароль',
    'New Password (confirm)' => 'Новий пароль (підтвердження)',
    'New Password and New Password (confirm) MUST match!' => 'Паролі повинні співпадати!',
    'No Permission(s)' => 'Немає дозволу (ів)',
    'No VPN profiles are available for your account.' => 'Немає доступних профілів VPN для вашого облікового запису.',
    'Node URL' => 'URL-адреса вузла',
    'Node(s)' => 'Вузол (вузли)',
    'OAuth' => 'Відкрита авторизація',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Отримайте новий файл конфігурації VPN для використання у вашому VPN-клієнті',
    'Offered Ports' => 'Пропоновані порти',
    'Offline' => 'Поза мережею',
    'Online' => 'В мережі',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Підтвердьте це лише тоді, коли ви намагаєтесь встановити VPN-з’єднання за допомогою цієї програмою!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Журнал сервера OpenVPN',
    'Password' => 'Пароль',
    'Permissions' => 'Дозволи',
    'Please sign in with your username and password.' => 'Будь ласка, увійдіть, використовуючи своє ім’я користувача та пароль.',
    'Port' => 'Порт',
    'Ports' => 'Порти',
    'Preferred Protocol' => 'Бажаний протокол',
    'Profile' => 'Профайл',
    //'Profile ID' => '',
    'Profile Usage' => 'Використання профайлу',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Профайл (и)',
    //'Proxy URL' => '',
    'Public Key' => 'Відкритий ключ',
    //'Refresh' => '',
    'Results' => 'Результат',
    'Revoke' => 'Відкликати',
    'Route(s)' => 'Маршрут/маршрути',
    'Search' => 'Пошук',
    'Select a profile and choose a name, e.g. "Phone".' => 'Виберіть профіль і оберіть ім’я, напр. "Телефон".',
    'Server' => 'сервер',
    'Sign In' => 'Увійти',
    'Sign Out' => 'Вийти',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Статистика',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Date/Time</em> повинно бути в UTC',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Поле <em>Дата/Час</em> приймає дані у форматі <code>Рік-місяць-день г:хв:сек</code>, e.g. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Надані вами облікові дані були невірними.',
    'The list of applications you authorized to create a VPN connection.' => 'Список програм, яким ви надали дозвіл на створення VPN-з’єднання.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Максимальна кількість одночасно підключених VPN-клієнтів у певний момент часу за останній тиждень',
    'The most recent VPN connections with this account.' => 'Останні VPN-з’єднання з цим обліковим записом',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Кількість поточних VPN клієнтів та максимально можлива кількість VPN клієнтів з розрахунку вказаного для цього профайлу адресного IP-простору',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Кількість унікальних гостьових користувачив підєднавшихся до VPN сервеса за останій тиждень',
    'The number of unique users connecting to the VPN service in the last week' => 'Кількість унікальних користувачів, які підключилися до послуги VPN за останній тиждень',
    'The table below shows the per profile VPN usage over the last week.' => 'У таблиці нижче показано використання VPN для кожного профілю за останній тиждень',
    'There are no results matching your criteria.' => 'Немає результатів, що відповідають вашим критеріям.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Цей сервер використовує зовнішній ресурс аутентифікації. Видалення даних облікового запису не завадить користувачу пройти автентифікацію (знову)!',
    'This user does not have any active configurations.' => 'У цього користувача немає активних конфігурацій.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Цей користувач не має жодних підключень.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Щоб зловмисні програми таємно не встановлювали VPN-з’єднання від вашого імені, вам слід спочатку затвердити цю програму.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Скористайтеся програмою WireGuard на своєму мобільному пристрої, щоб відсканувати цей QR-код.',
    'User ID' => 'ID користувача',
    'Username' => 'Ім’я користвача',
    'Users' => 'Користувачі',
    'VPN Portal' => 'VPN портал',
    'Version' => 'Версія',
    'Welcome to this VPN service!' => 'Ласкаво просимо до нашої послуги VPN!',
    'Why is this necessary?' => 'Чому це потрібно?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Конфігурація WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Нижче ви можете завантажити детальну статистику використання VPN.',
    'You cannot manage your own user account.' => 'Ви не можете керувати власним обліковим записом користувача.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Ви досягли максимальної кількості дозволених активних конфігурацій VPN. Спочатку видаліть деякі з них.',
    'Your account does not have access to any VPN profile.' => 'Ваш обліковий запис не має доступу до жодного профілю VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Срок дії вашої нової конфігурації сплине %expiryDate%. Поверніться сюди, щоб отримати нову конфігурацію після закінчення терміну дії!',
];
