<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Aktif (Maks #Mevcut) Bağlantılar',
    '#Connections in 5 minute intervals' => '#5 dakikalık aralıklarla bağlantılar',
    '#Unique Guest Users' => '#Tekil Misafir Kullanıcılar',
    '#Unique Users' => '#Tekil Kullanıcılar',
    '#Unique users and max #connections per day' => '#Günlük tekil kullanıcılar ve maksimum #bağlantılar',
    'ACL Permission List' => 'ACL İzin Listesi',
    'Account' => 'Hesap',
    'Active' => 'Aktif',
    'Active Configurations' => 'Aktif Konfigürasyonlar',
    //'Additional Credential' => '',
    'Aggregated' => 'Birleştirilmiş',
    'All' => 'Tümü',
    'An application attempts to establish a VPN connection.' => 'Bir uygulama VPN bağlantısı kurmaya çalışıyor.',
    'An error occurred.' => 'Bir hata oluştu.',
    'Application Usage' => 'Uygulama Kullanımı',
    'Approve' => 'Onayla',
    'Approve Application' => 'Uygulamayı Onayla',
    'Authentication Data' => 'Kimlik Doğrulama Verileri',
    'Authorized Applications' => 'Yetkilendirilmiş Uygulamalar',
    'Authorized On' => 'Yetkilendirme Tarihi',
    'Available Profiles' => 'Mevcut Profiller',
    'Block LAN' => 'LAN\'i Engelle',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU Kullanımı:',
    'Change Password' => 'Şifre Değiştir',
    'Configurations' => 'Konfigürasyonlar',
    'Confirm' => 'Onayla',
    'Connected' => 'Bağlı',
    'Connections' => 'Bağlantılar',
    'Created On' => 'Oluşturulma Tarihi',
    'Current Password' => 'Mevcut Şifre',
    'Current Password not correct!' => 'Mevcut Şifre doğru değil!',
    'Currently there are no clients connected to this profile.' => 'Şu anda bu profile bağlı hiçbir istemci yok.',
    'DNS Search Domain(s)' => 'DNS Arama Alanı',
    'DNS Server(s)' => 'DNS Sunucusu',
    'Danger Zone' => 'Tehlike Bölgesi',
    //'Database' => '',
    'Date/Time' => 'Tarih/Saat',
    'Default Gateway' => 'Varsayılan Ağ Geçidi',
    'Delete' => 'Sil',
    'Delete Account' => 'Hesabı Sil',
    'Delete Account Data' => 'Hesap Verilerini Sil',
    'Disable Account' => 'Hesabı Devre Dışı Bırak',
    'Disabled' => 'Devre Dışı',
    'Disconnected' => 'Bağlantı Kesildi',
    'Distribution of unique users over the VPN applications.' => 'VPN uygulamaları üzerindeki tekil kullanıcıların dağılımı.',
    'Download' => 'İndir',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'VPN konfigürasyonlarını indirmek yasaktır. Lütfen bir VPN uygulaması kullanın.',
    //'Driver' => '',
    'Enable Account' => 'Hesabı Etkinleştir',
    'Error' => 'Hata',
    'Excluded Route(s)' => 'Hariç Tutulan Rotalar',
    'Expires On' => 'Bitiş Tarihi',
    'Export (CSV)' => 'Dışa Aktar (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Belirli bir zamanda IPv4 veya IPv6 adresini kullanan kullanıcı tanımlayıcısını bulun.',
    'Fingerprint' => 'Parmak İzi',
    'Here you can change the password for your account.' => 'Burada hesabınızın şifresini değiştirebilirsiniz.',
    'Home' => 'Ana Sayfa',
    'Hostname' => 'Sunucu Adı',
    'IP Address' => 'IP Adresi',
    'IPs' => 'IP\'ler',
    'IPv4 Prefix' => 'IPv4 Öneki',
    'IPv6 Prefix' => 'IPv6 Öneki',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Bu konfigürasyonu WireGuard uygulamanıza içe aktarın veya kopyalayıp yapıştırın.',
    'Info' => 'Bilgi',
    'Issues' => 'Sorunlar',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Canlı',
    'Log' => 'Günlük',
    'MTU' => 'MTU',
    //'Maintenance' => '',
    'Max #Connections' => 'Maks #Bağlantılar',
    'More' => 'Daha Fazla',
    'N/A' => 'Mevcut Değil',
    'Name' => 'İsim',
    'New Configuration' => 'Yeni Konfigürasyon',
    'New Password' => 'Yeni Şifre',
    'New Password (confirm)' => 'Yeni Şifre (onayla)',
    'New Password and New Password (confirm) MUST match!' => 'Yeni Şifre ve Yeni Şifre (onayla) BİRBİRİYLE UYUMLU OLMALIDIR!',
    'No Permission(s)' => 'İzin Yok',
    'No VPN profiles are available for your account.' => 'Hesabınız için uygun VPN profili bulunmamaktadır.',
    'Node URL' => 'Düğüm URL\'si',
    'Node(s)' => 'Düğüm(ler)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'VPN istemcinizde kullanmak için yeni bir VPN konfigürasyon dosyası edinin.',
    'Offered Ports' => 'Sunulan Portlar',
    'Offline' => 'Çevrimdışı',
    'Online' => 'Çevrimiçi',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Bu uygulama ile bir VPN bağlantısı kurmaya çalıştığınızda bunu onaylayın!',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (TCP Tercihli)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (UDP Tercihli)',
    'OpenVPN Server Log' => 'OpenVPN Sunucu Günlüğü',
    'Password' => 'Şifre',
    'Permissions' => 'İzinler',
    'Please sign in with your username and password.' => 'Lütfen kullanıcı adınız ve şifreniz ile giriş yapın.',
    'Port' => 'Port',
    'Ports' => 'Portlar',
    'Preferred Protocol' => 'Tercih Edilen Protokol',
    'Profile' => 'Profil',
    'Profile ID' => 'Profil ID\'si',
    'Profile Usage' => 'Profil Kullanımı',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(ler)',
    //'Proxy URL' => '',
    'Public Key' => 'Açık Anahtar',
    'Refresh' => 'Yenile',
    'Results' => 'Sonuçlar',
    'Revoke' => 'İptal Et',
    'Route(s)' => 'Rota(lar)',
    'Search' => 'Ara',
    'Select a profile and choose a name, e.g. "Phone".' => 'Bir profil seçin ve bir isim belirleyin, örneğin "Telefon".',
    'Server' => 'Sunucu',
    'Sign In' => 'Giriş Yap',
    'Sign Out' => 'Çıkış Yap',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'İstatistikler',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Tarih/Saat</em> UTC formatında OLMALIDIR.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '<em>Tarih/Saat</em> alanı <code>Y-m-d H:i:s</code> formatındaki tarihleri kabul eder, örneğin <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Sağladığınız kimlik bilgileri doğru değildir.',
    'The list of applications you authorized to create a VPN connection.' => 'VPN bağlantısı oluşturmak için yetkilendirdiğiniz uygulamaların listesi.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Son hafta içinde belirli bir anda eşzamanlı olarak bağlanan maksimum VPN istemci sayısı',
    'The most recent VPN connections with this account.' => 'Bu hesapla yapılan en son VPN bağlantıları.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Şu anda bağlı olan VPN istemcilerinin sayısı ve bu profil için mevcut IP alanına göre bağlanabilecek maksimum VPN istemci sayısı.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Son hafta içinde VPN hizmetine bağlanan tekil misafir kullanıcı sayısı',
    'The number of unique users connecting to the VPN service in the last week' => 'Son hafta içinde VPN hizmetine bağlanan tekil kullanıcı sayısı',
    'The table below shows the per profile VPN usage over the last week.' => 'Aşağıdaki tablo, son hafta boyunca profil başına VPN kullanımını göstermektedir.',
    'There are no results matching your criteria.' => 'Kriterlerinize uygun sonuç bulunamadı.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Bu sunucu harici bir kimlik doğrulama kaynağı kullanmaktadır. Hesap verilerini silmek, kullanıcının (tekrar) kimlik doğrulamasını engellemez!',
    'This user does not have any active configurations.' => 'Bu kullanıcının herhangi bir aktif konfigürasyonu yok.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Bu kullanıcının herhangi bir bağlantısı yok.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Kötü niyetli uygulamaların sizin adınıza gizlice bir VPN bağlantısı kurmasını önlemek için, önce bu uygulamayı açıkça onaylamanız gerekir.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Bu QR kodunu tarayabilmek için mobil cihazınızda WireGuard uygulamasını kullanın.',
    'User ID' => 'Kullanıcı ID\'si',
    'Username' => 'Kullanıcı Adı',
    'Users' => 'Kullanıcılar',
    'VPN Portal' => 'VPN Portalı',
    'Version' => 'Sürüm',
    'Welcome to this VPN service!' => 'VPN hizmetine hoş geldiniz!',
    'Why is this necessary?' => 'Bu neden gerekli?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard Konfigürasyonu',
    'You can download the detailed VPN usage statistics below.' => 'Aşağıda detaylı VPN kullanım istatistiklerini indirebilirsiniz.',
    'You cannot manage your own user account.' => 'Kendi kullanıcı hesabınızı yönetemezsiniz.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'İzin verilen maksimum aktif VPN konfigürasyonu sayısına ulaştınız. Önce bazılarını silin.',
    'Your account does not have access to any VPN profile.' => 'Hesabınızın herhangi bir VPN profiline erişimi yok.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Yeni konfigürasyonunuz %expiryDate% tarihinde sona erecek. Süresi dolduktan sonra yeni bir konfigürasyon almak için buraya geri dönün!',
];
