<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '#Ühendused 5-minutiliste intervallidega',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Unikaalsed kasutajad',
    '#Unique users and max #connections per day' => '#Unikaalsed kasutajad ja #ühendusi päevas',
    'ACL Permission List' => 'ACL õiguste loend',
    'Account' => 'Konto',
    'Active' => 'Aktiivne',
    'Active Configurations' => 'Aktiivsed seadistused',
    //'Additional Credential' => '',
    'Aggregated' => 'Koondatud',
    'All' => 'Kõik',
    'An application attempts to establish a VPN connection.' => 'Rakendus proovib luua VPN ühendust.',
    'An error occurred.' => 'Tekkis viga',
    'Application Usage' => 'Rakenduse kasutus',
    'Approve' => 'Heakskiitmine',
    'Approve Application' => 'Rakenduse heakskiitmine',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Lubatud rakendused',
    'Authorized On' => 'Millal heaks kiidetud',
    'Available Profiles' => 'Olemasolevad profiilid',
    'Block LAN' => 'Blokeeri LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU kasutus',
    'Change Password' => 'Muuda parooli',
    'Configurations' => 'Seadistused',
    'Confirm' => 'Kinnita',
    'Connected' => 'Ühendatud',
    'Connections' => 'Ühendused',
    'Created On' => 'Loodud',
    'Current Password' => 'Praegune salasõna',
    'Current Password not correct!' => 'See salasõna ei ole õige!',
    'Currently there are no clients connected to this profile.' => 'Praegu ei ole selle profiiliga kliente ühendatud',
    'DNS Search Domain(s)' => 'DNS otsi domeen(e)',
    'DNS Server(s)' => 'DNS server(id)',
    'Danger Zone' => 'Ohutsoon',
    //'Database' => '',
    'Date/Time' => 'Kuupäev/kellaaeg',
    'Default Gateway' => 'Vaikelüüs',
    'Delete' => 'Kustuta',
    'Delete Account' => 'Kustuta konto',
    'Delete Account Data' => 'Kustuta konto andmed',
    'Disable Account' => 'Desaktiveeri konto',
    'Disabled' => 'Desaktiveeritud',
    'Disconnected' => 'Lahti ühendatud',
    'Distribution of unique users over the VPN applications.' => 'Unikaalsete kasutajate jaotus VPN rakenduste vahel',
    'Download' => 'Allalaadimine',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'VPNi seadistuste allalaadimine ei ole lubatud. Palun kasuta VPN rakendust.',
    //'Driver' => '',
    'Enable Account' => 'Luba konto',
    'Error' => 'Viga',
    'Excluded Route(s)' => 'Välistatud marsruut/marsruudid',
    'Expires On' => 'Aegub',
    'Export (CSV)' => 'Eksport (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Leia kasutajaidentifikaator, millega kasutati konkreetsel ajahetkel IPv4 või IPv6 aadressi.',
    'Fingerprint' => 'Sõrmejälg',
    'Here you can change the password for your account.' => 'Siin saad oma konto parooli muuta.',
    'Home' => 'Avaleht',
    'Hostname' => 'Hosti nimi',
    'IP Address' => 'IP-aadress',
    'IPs' => 'IP-d',
    'IPv4 Prefix' => 'IPv4 prefiks',
    'IPv6 Prefix' => 'IPv6 prefiks',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Impordi või lõika-ja-kleebi see seadistus oma WireGuard rakendusse.',
    'Info' => 'Info',
    'Issues' => 'Probleeme',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Käigus',
    'Log' => 'Logi',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Maksimaalselt #ühendusi',
    'More' => 'Veel',
    'N/A' => 'N/A',
    'Name' => 'Nimi',
    'New Configuration' => 'Uus seadistus',
    'New Password' => 'Uus parool',
    'New Password (confirm)' => 'Uus parool (veel kord)',
    'New Password and New Password (confirm) MUST match!' => 'Uus parool tuleb mõlemal korral ühtemoodi sisestada!',
    'No Permission(s)' => 'Õigusi ei ole',
    'No VPN profiles are available for your account.' => 'Su konto jaoks ei ole VPN profiile saadaval.',
    'Node URL' => 'Sõlme URL',
    'Node(s)' => 'Sõlm(ed)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Hangi uus VPNi seadistusfail oma VPN kliendi jaoks.',
    'Offered Ports' => 'Pakutavad pordid',
    'Offline' => 'Võrguühenduseta',
    'Online' => 'Võrguühendusega',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Luba rakendus ainult juhul, kui püüad sellega VPN-ühendust luua!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN serveri logi',
    'Password' => 'Parool',
    'Permissions' => 'Õigused',
    'Please sign in with your username and password.' => 'Palun logi oma kasutajanime ja parooliga sisse.',
    'Port' => 'Port',
    'Ports' => 'Pordid',
    'Preferred Protocol' => 'Eelistatud protokoll',
    'Profile' => 'Profiil',
    //'Profile ID' => '',
    'Profile Usage' => 'Profiili kasutus',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profiil(id)',
    //'Proxy URL' => '',
    'Public Key' => 'Avalik võti',
    //'Refresh' => '',
    'Results' => 'Tulemused',
    'Revoke' => 'Tühista',
    'Route(s)' => 'Marsruut/marsruudid',
    'Search' => 'Otsi',
    'Select a profile and choose a name, e.g. "Phone".' => 'Vali profiil ja pane sellele nimi, näiteks “Telefon”.',
    'Server' => 'Server',
    'Sign In' => 'Logi sisse',
    'Sign Out' => 'Logi välja',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistika',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Kuupäev/kellaaeg</em> peab olema UTC-s.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Välja <em>Kuupäev/kellaaeg</em> vorming: <code>aasta-kuu-päev tund:minut:sekund</code>, näiteks <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Kasutajakonto andmed ei olnud õiged.',
    'The list of applications you authorized to create a VPN connection.' => 'Rakenduste nimekiri, millel oled lubanud VPN ühendust luua.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Samaaegselt ühendatud VPN-klientide arvu maksimum eelmise nädala konkreetsel ajahetkel',
    'The most recent VPN connections with this account.' => 'Selle konto viimane VPNi ühendus',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'VPN teenuse unikaalsete kasutajate arv viimasel nädalal.',
    'The table below shows the per profile VPN usage over the last week.' => 'Alltoodud tabel näitab profiilide kaupa VPN kasutust viimasel nädalal.',
    'There are no results matching your criteria.' => 'Otsingutingimustele vastavaid tulemusi ei leitud.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Server kasutab välist autentimisallikat. Konto andmete kustutamine ei hoia ära kasutaja taasautentimist!',
    'This user does not have any active configurations.' => 'Sel kasutajal ei ole aktiivseid ühendusi.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Sel kasutajal ei ole ühendusi.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Vältimaks kahjurrakenduste poolt Sinu nimel salaja VPN ühenduste loomist, pead selle rakenduse esmalt ilmutatult heaks kiitma.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Selle QR koodi skaneerimiseks kasuta oma mobiiliseadmes WireGuardi rakendust.',
    'User ID' => 'Kasutaja ID',
    'Username' => 'Kasutajanimi',
    'Users' => 'Kasutajad',
    'VPN Portal' => 'VPN-portaal',
    'Version' => 'Versioon',
    'Welcome to this VPN service!' => 'Tere tulemast VPN teenusesse!',
    'Why is this necessary?' => 'Miks seda vaja on?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuardi seadistus',
    'You can download the detailed VPN usage statistics below.' => 'Detailse VPNi kasutusstatistika saad allpool alla laadida.',
    'You cannot manage your own user account.' => 'Sa ei saa ise enda kasutajakontot hallata.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Sul on lubatud aktiivsete VPN seadistuste arv täis. Kustuta esmalt mõned ära.',
    'Your account does not have access to any VPN profile.' => 'Su kontol ei ole juurdepääsu ühelegi VPN profiilile.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Su uue seadistuse aegumiskuupäev on %expiryDate%. Pärast aegumist tule palun tagasi uut seadistust saama.',
];
