<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Conexiones (Máximas #Disponibles) Activas',
    '#Connections in 5 minute intervals' => '#Conexiones en intervalos de 5 minutos',
    '#Unique Guest Users' => '#Usuarios Invitados Únicos',
    '#Unique Users' => '#Usuarios Únicos',
    '#Unique users and max #connections per day' => '#Usuarios únicos y máximas #conexiones por día',
    'ACL Permission List' => 'Lista de Permisos ACL',
    'Account' => 'Cuenta',
    'Active' => 'Activo',
    'Active Configurations' => 'Configuraciones Activas',
    //'Additional Credential' => '',
    'Aggregated' => 'Agregado',
    'All' => 'Todos',
    'An application attempts to establish a VPN connection.' => 'Una aplicación intenta establecer una conexión VPN.',
    'An error occurred.' => 'Ocurrió un error.',
    'Application Usage' => 'Uso de la Aplicación',
    'Approve' => 'Aprobar',
    'Approve Application' => 'Aprobar Aplicación',
    'Authentication Data' => 'Datos de Autenticación',
    'Authorized Applications' => 'Aplicaciones Autorizadas',
    'Authorized On' => 'Autorizado el',
    'Available Profiles' => 'Perfiles Disponibles',
    'Block LAN' => 'Bloquear LAN',
    'CA' => 'CA (Autoridad certificadora)',
    'CPU Usage:' => 'Uso de CPU:',
    'Change Password' => 'Cambiar Contraseña',
    'Configurations' => 'Configuraciones',
    'Confirm' => 'Confirmar',
    'Connected' => 'Conectado',
    'Connections' => 'Conexiones',
    'Created On' => 'Creado el',
    'Current Password' => 'Contraseña Actual',
    'Current Password not correct!' => '¡Contraseña Actual no es correcta!',
    'Currently there are no clients connected to this profile.' => 'Actualmente no hay clientes conectados a este perfil.',
    'DNS Search Domain(s)' => 'Dominio(s) de Búsqueda DNS',
    'DNS Server(s)' => 'Servidor(es) DNS',
    'Danger Zone' => 'Zona Peligrosa',
    //'Database' => '',
    'Date/Time' => 'Fecha/Hora',
    'Default Gateway' => 'Gateway por Defecto',
    'Delete' => 'Borrar',
    'Delete Account' => 'Borrar Cuenta',
    'Delete Account Data' => 'Borrar Datos de Cuenta',
    'Disable Account' => 'Desactivar Cuenta',
    'Disabled' => 'Desactivado',
    'Disconnected' => 'Desconectado',
    'Distribution of unique users over the VPN applications.' => 'Distribución de usuarios únicos a través de las aplicaciones VPN.',
    'Download' => 'Descarga',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'No se permite descargar configuraciones VPN. Por favor, use una aplicación VPN.',
    //'Driver' => '',
    'Enable Account' => 'Habilitar Cuenta',
    //'Error' => '',
    'Excluded Route(s)' => 'Ruta(s) Excluídas',
    'Expires On' => 'Expira el',
    'Export (CSV)' => 'Exportar (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Encuentre el identificador de usuario que utilizó una dirección IPv4 o IPv6 en un momento determinado.',
    'Fingerprint' => 'Huella',
    'Here you can change the password for your account.' => 'Aquí puede cambiar la contraseña de su cuenta.',
    'Home' => 'Inicio',
    //'Hostname' => '',
    'IP Address' => 'Dirección IP',
    //'IPs' => '',
    'IPv4 Prefix' => 'Prefijo IPv4',
    'IPv6 Prefix' => 'Prefijo IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importe, o copie y pegue esta configuración en su aplicación WireGuard.',
    'Info' => 'Información',
    'Issues' => 'Problemas',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'En vivo',
    'Log' => 'Registro',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => '#Conexiones Máximas',
    'More' => 'Más',
    'N/A' => 'N/D',
    'Name' => 'Nombre',
    'New Configuration' => 'Nueva Configuración',
    'New Password' => 'Nueva Contraseña',
    'New Password (confirm)' => 'Nueva Contraseña (confirmar)',
    'New Password and New Password (confirm) MUST match!' => '¡Nueva Contraseña y Nueva Contraseña (confirmar) DEBEN coincidir!',
    'No Permission(s)' => 'Sin Permiso(s)',
    'No VPN profiles are available for your account.' => 'No hay perfiles VPN disponibles para su cuenta.',
    'Node URL' => 'URL de Nodo',
    'Node(s)' => 'Nodo(s)',
    //'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenga un nuevo archivo de configuración VPN para usar en su cliente VPN.',
    'Offered Ports' => 'Puertos Ofrecidos',
    'Offline' => 'Desconectado',
    'Online' => 'Conectado',
    'Only approve this when you are trying to establish a VPN connection with this application!' => '¡Apruebe esto solo cuando intente establecer una conexión VPN con esta aplicación!',
    //'OpenVPN' => '',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Preferir TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Preferir UDP)',
    'OpenVPN Server Log' => 'Registro del Servidor OpenVPN',
    'Password' => 'Contraseña',
    'Permissions' => 'Permisos',
    'Please sign in with your username and password.' => 'Por favor, inicie sesión con su nombre de usuario y contraseña.',
    'Port' => 'Puerto',
    'Ports' => 'Puertos',
    'Preferred Protocol' => 'Protocolo Preferido',
    'Profile' => 'Perfil',
    'Profile ID' => 'ID de Perfil',
    'Profile Usage' => 'Uso del Perfil',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Perfil(es)',
    //'Proxy URL' => '',
    'Public Key' => 'Clave Pública',
    'Refresh' => 'Refrescar',
    'Results' => 'Resultados',
    'Revoke' => 'Revocar',
    'Route(s)' => 'Ruta(s)',
    'Search' => 'Buscar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Seleccione un perfil y elija un nombre, por ejemplo "Teléfono".',
    'Server' => 'Servidor',
    'Sign In' => 'Iniciar Sesión',
    'Sign Out' => 'Cerrar Sesión',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Estadísticas',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>Fecha/Hora</em> DEBE esta en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'El campo <em>Fecha/Hora</em> acepta fechas con el formato <code>Y-m-d H:i:s</code>, por ejemplo <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Las credenciales que proporcionó no eran correctas.',
    'The list of applications you authorized to create a VPN connection.' => 'La lista de aplicaciones que usted autorizó para crear una conexión VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'El número máximo de clientes VPN conectados simultáneamente en un momento determinado durante la última semana',
    'The most recent VPN connections with this account.' => 'Las conexiones VPN más recientes con esta cuenta.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'El número de clientes VPN conectados actualmente, y el número máximo posible de clientes VPN conectados en base al espacio IP disponible para este perfil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'El número de usuarios invitados únicos que se conectaron al servicio VPN en la última semana',
    'The number of unique users connecting to the VPN service in the last week' => 'El número de usuarios únicos que se conectaron al servicio VPN en la última semana',
    'The table below shows the per profile VPN usage over the last week.' => 'La siguiente tabla muestra el uso de VPN por perfil en la última semana.',
    'There are no results matching your criteria.' => 'No hay resultados que coincidan con sus criterios.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Este servidor utiliza una fuente de autenticación externa. ¡Eliminando los datos de la cuenta no evitará que el usuario se autentique (de nuevo)!',
    'This user does not have any active configurations.' => 'Este usuario no tiene ninguna configuración activa.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Este usuario no tiene ninguna conexión.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para evitar que aplicaciones maliciosas establezcan en secreto una conexión VPN en su nombre, debe aprobar explícitamente esta aplicación primero.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilice la aplicación WireGuard en su dispositivo móvil para escanear este código QR.',
    'User ID' => 'ID de Usuario',
    'Username' => 'Nombre de Usuario',
    'Users' => 'Usuarios',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versión',
    'Welcome to this VPN service!' => '¡Bienvenido a este servicio VPN!',
    'Why is this necessary?' => '¿Por qué es necesario esto?',
    //'WireGuard' => '',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Configuración WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Puede descargar las estadísticas detalladas de uso de VPN a continuación.',
    'You cannot manage your own user account.' => 'No puede administrar su propia cuenta de usuario.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Ha alcanzado el número máximo de configuraciones VPN activas permitidas. Elimine algunas primero.',
    'Your account does not have access to any VPN profile.' => 'Su cuenta no tiene acceso a ningún perfil VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Su nueva configuración caducará el %expiryDate%. ¡Vuelva aquí para obtener una nueva configuración después de vencimiento!',
];
