<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => 'Antal aktive forbindelser (maks. antal til rådighed)',
    '#Connections in 5 minute intervals' => 'Antal forbindelser i femminutters intervaller',
    '#Unique Guest Users' => 'Antal unikke gæstebrugere',
    '#Unique Users' => 'Antal unikke brugere',
    '#Unique users and max #connections per day' => 'Antal unikke brugere og maks. antal forbindelser per dag',
    'ACL Permission List' => 'ACL-tilladelser',
    'Account' => 'Konto',
    'Active' => 'Aktiv',
    'Active Configurations' => 'Aktive konfigurationer',
    //'Additional Credential' => '',
    'Aggregated' => 'Sammenlagt',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => 'En applikation prøver at oprette en VPN-forbindelse',
    'An error occurred.' => 'Der opstod en fejl.',
    'Application Usage' => 'Applikationens forbrug',
    'Approve' => 'Godkend',
    'Approve Application' => 'Godkend applikation',
    'Authentication Data' => 'Autentifikationsdata',
    'Authorized Applications' => 'Autoriserede applikationer',
    'Authorized On' => 'Autoriseret',
    'Available Profiles' => 'Profiler til rådighed',
    'Block LAN' => 'Blokér LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU-forbrug:',
    'Change Password' => 'Skift adgangskode',
    'Configurations' => 'Konfigurationer',
    'Confirm' => 'Bekræft',
    'Connected' => 'Forbundet',
    'Connections' => 'Forbindelser',
    'Created On' => 'Oprettet',
    'Current Password' => 'Nuværende adgangskode',
    'Current Password not correct!' => 'Nuværende adgangskode er ikke rigtig!',
    'Currently there are no clients connected to this profile.' => 'For øjeblikket er der ingen klienter forbundet til profilen her.',
    'DNS Search Domain(s)' => 'DNS-søgedomæne(r)',
    'DNS Server(s)' => 'DNS-server(e)',
    'Danger Zone' => 'Farezone',
    'Database' => 'Database',
    'Date/Time' => 'Dato/klokkeslæt',
    'Default Gateway' => 'Standard-gateway',
    'Delete' => 'Slet',
    'Delete Account' => 'Slet konto',
    'Delete Account Data' => 'Slet kontodata',
    'Disable Account' => 'Deaktivér konto',
    'Disabled' => 'Deaktiveret',
    'Disconnected' => 'Ikke forbundet',
    'Distribution of unique users over the VPN applications.' => 'Fordeling af unikke brugere på VPN-applikationerne.',
    'Download' => 'Download',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Det er ikke tilladt at downloade VPN-konfigurationer. Brug venligst en VPN-applikation.',
    'Driver' => 'Driver',
    'Enable Account' => 'Aktivér konto',
    'Error' => 'Fejl',
    'Excluded Route(s)' => 'Udelukkede ruter',
    'Expires On' => 'Udløber',
    'Export (CSV)' => 'Eksportér (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Find ID for brugeren som brugte en IPv4- eller IPv6-adresse på et bestemt tidspunkt.',
    'Fingerprint' => 'Fingeraftryk',
    'Here you can change the password for your account.' => 'Her kan du ændre adgangskoden til din konto.',
    'Home' => 'Hjem',
    'Hostname' => 'Værtsnavn',
    'IP Address' => 'IP-adresse',
    'IPs' => 'IP\'er',
    'IPv4 Prefix' => 'IPv4-præfiks',
    'IPv6 Prefix' => 'IPv6-præfiks',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importér eller copy-paste konfigurationen her til din WireGuard-applikation.',
    'Info' => 'Oplysninger',
    'Issues' => 'Problemer',
    //'Keepalive' => '',
    'Last Used' => 'Senest brugt',
    'Live' => 'Lige nu',
    'Log' => 'Log',
    'MTU' => 'MTU',
    //'Maintenance' => '',
    'Max #Connections' => 'Maks. antal forbindelser til rådighed',
    'More' => 'Mere',
    'N/A' => 'Ikke til rådighed',
    'Name' => 'Navn',
    'New Configuration' => 'Ny konfiguration',
    'New Password' => 'Ny adgangskode',
    'New Password (confirm)' => 'Ny adgangskode (bekræft)',
    'New Password and New Password (confirm) MUST match!' => 'Ny adgangskode og Ny adgangskode (bekræft) skal være identiske!',
    'No Permission(s)' => 'Ingen tilladelse(r)',
    'No VPN profiles are available for your account.' => 'Der er ingen VPN-profiler tilknyttet din konto.',
    'Node URL' => 'Node-URL',
    'Node(s)' => 'Node(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Få en ny VPN-konfigurationsfil til brug i din VPN-klient.',
    'Offered Ports' => 'Tilbudte porte',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Det her skal du kun godkende hvis du prøver at oprette en VPN-forbindelse med den her applikation!',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (forrang for TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (forrang for UDP)',
    'OpenVPN Server Log' => 'OpenVPN-serverlog',
    'Password' => 'Adgangskode',
    'Permissions' => 'Tilladelser',
    'Please sign in with your username and password.' => 'Log ind med dit brugernavn og din adgangskode.',
    'Port' => 'Port',
    'Ports' => 'Porte',
    'Preferred Protocol' => 'Foretrukne protokol',
    'Profile' => 'Profil',
    'Profile ID' => 'Profil-ID',
    'Profile Usage' => 'Forbrug for profil',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(er)',
    //'Proxy URL' => '',
    'Public Key' => 'Offentlig nøgle',
    'Refresh' => 'Genopfrisk',
    'Results' => 'Resultater',
    'Revoke' => 'Ophæv',
    'Route(s)' => 'Rute(r)',
    'Search' => 'Søg',
    'Select a profile and choose a name, e.g. "Phone".' => 'Vælg en profil og tilføj et navn, f.eks. "Telefon".',
    'Server' => 'Server',
    'Sign In' => 'Log ind',
    'Sign Out' => 'Log ud',
    'Sorted by "Last Used", most recently used first.' => 'Sorteret efter "Senest brugt", med senest brugte først.',
    'Stats' => 'Statistik',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Dato/klokkeslæt</em> SKAL være i UTC-format.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Feltet <em>Dato/klokkeslæt</em> accepterer datoer i formatet <code>Y-m-d H:i:s</code>, f.eks. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'De indtastede brugeroplysninger er ikke korrekte.',
    'The list of applications you authorized to create a VPN connection.' => 'Listen over applikationer du har autoriseret til at oprette en VPN-forbindelse.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Maks. antal samtidigt tilsluttede VPN-klienter på et givet tidspunkt den seneste uge',
    'The most recent VPN connections with this account.' => 'Seneste VPN-tilslutninger med den her konto.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Antal VPN-klienter på tjenesten lige nu samt det maksimalt mulige antal tilsluttede VPN-klienter vurderet ud fra det IP-rum profilen her har til rådighed.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Antal unikke gæstebrugere på VPN-tjenesten den seneste uge',
    'The number of unique users connecting to the VPN service in the last week' => 'Antal unikke brugere på VPN-tjenesten den seneste uge',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabellen nedenfor viser VPN-forbruger per profil den seneste uge.',
    'There are no results matching your criteria.' => 'Der er ingen resultater der matcher dine kriterier',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Serveren her bruger en ekstern autentifikationskilde. Sletning af kontodataene vil <em>ikke</em> afskære brugeren fra at logge ind (på ny)!',
    'This user does not have any active configurations.' => 'Den her bruger har ingen aktive konfigurationer.',
    'This user does not have any authorized applications.' => 'Brugeren her har ingen godkendte applikationer.',
    'This user does not have any connections.' => 'Den her bruger har ingen aktive forbindelser.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'For at forhindre ondsindede applikationer i at oprette en VPN-forbindelse med din konto skal du først autorisere den her applikation.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Skan QR-koden her med WireGuard-app\'en på din mobile enhed.',
    'User ID' => 'Bruger-ID',
    'Username' => 'Brugernavn',
    'Users' => 'Bruger',
    'VPN Portal' => 'VPN-portal',
    'Version' => 'Udgave',
    'Welcome to this VPN service!' => 'Velkommen til denne VPN-tjeneste!',
    'Why is this necessary?' => 'Hvorfor er det her nødvendigt?',
    'WireGuard' => 'WireGuard',
    'WireGuard (TCP)' => 'WireGuard (TCP)',
    'WireGuard (UDP)' => 'WireGuard (UDP)',
    'WireGuard Configuration' => 'WireGuard-konfiguration',
    'You can download the detailed VPN usage statistics below.' => 'Du kan downloade detaljeret VPN-brugsstatistik nedenfor.',
    'You cannot manage your own user account.' => 'Du kan ikke administrere din egen konto.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Du har nået det maksimale antal tilladte aktive VPN-konfigurationer. Slet først en eller flere.',
    'Your account does not have access to any VPN profile.' => 'Din konto har ikke adgang til nogen VPN-profil.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Din nye konfiguration vil udløbe den %expiryDate%. Kom tilbage hertil og få en ny konfiguration når den nuværende er udløbet!',
];
