<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Aktivních (max #dostupných) připojení',
    '#Connections in 5 minute intervals' => '#Připojení v 5 minutových intervalech',
    '#Unique Guest Users' => '#Jedinečných externích uživatelů',
    '#Unique Users' => '#Jedinečných uživatelů',
    '#Unique users and max #connections per day' => '#Jedinečných uživatelů a max. #připojení za den',
    'ACL Permission List' => 'ACL seznam oprávnění',
    'Account' => 'Účet',
    'Active' => 'Aktivní',
    'Active Configurations' => 'Aktivní konfigurace',
    //'Additional Credential' => '',
    'Aggregated' => 'Agregované',
    'All' => 'Vše',
    'An application attempts to establish a VPN connection.' => 'Aplikace se pokouší navázat VPN spojení.',
    'An error occurred.' => 'Došlo k chybě.',
    'Application Usage' => 'Použití aplikace',
    'Approve' => 'Schválit',
    'Approve Application' => 'Schválit aplikaci',
    'Authentication Data' => 'Autentizační data',
    'Authorized Applications' => 'Autorizované aplikace',
    'Authorized On' => 'Autorizováno dne',
    'Available Profiles' => 'Dostupné profily',
    'Block LAN' => 'Blokovat LAN',
    'CA' => 'Certifikační Autorita',
    'CPU Usage:' => 'Využití CPU:',
    'Change Password' => 'Změnit heslo',
    'Configurations' => 'Konfigurace',
    'Confirm' => 'Potvrdit',
    'Connected' => 'Připojeno',
    'Connections' => 'Připojení',
    'Created On' => 'Vytvořeno dne',
    'Current Password' => 'Aktuální heslo',
    'Current Password not correct!' => 'Aktuální heslo není správné!',
    'Currently there are no clients connected to this profile.' => 'Momentálně k tomuto profilu není připojen žádný klient.',
    'DNS Search Domain(s)' => 'DNS vyhledávací domény',
    'DNS Server(s)' => 'DNS servery',
    'Danger Zone' => 'Nebezpečná zóna',
    //'Database' => '',
    'Date/Time' => 'Datum/Čas',
    'Default Gateway' => 'Výchozí brána',
    'Delete' => 'Smazat',
    'Delete Account' => 'Smazat účet',
    'Delete Account Data' => 'Smazat data účtu',
    'Disable Account' => 'Zakázat účet',
    'Disabled' => 'Zakázano',
    'Disconnected' => 'Odpojeno',
    'Distribution of unique users over the VPN applications.' => 'Rozložení jedinečných uživatelů mezi VPN aplikacemi.',
    'Download' => 'Stáhnout',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Stahování VPN konfigurací není povoleno. Použijte prosím VPN aplikaci.',
    //'Driver' => '',
    'Enable Account' => 'Povolit účet',
    'Error' => 'Chyba',
    'Excluded Route(s)' => 'Vyloučeny trasy',
    'Expires On' => 'Vyprší dne',
    'Export (CSV)' => 'Exportovat (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Najděte identifikátor uživatele, který používal IPv4 nebo IPv6 adresu v určitém okamžiku.',
    'Fingerprint' => 'Otisk prstu',
    'Here you can change the password for your account.' => 'Zde můžete změnit heslo k vašemu účtu.',
    'Home' => 'Domů',
    'Hostname' => 'Hostname',
    'IP Address' => 'IP adresa',
    'IPs' => 'IP',
    'IPv4 Prefix' => 'IPv4 prefix',
    'IPv6 Prefix' => 'IPv6 prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importujte nebo zkopírujte tuto konfiguraci do Vaší WireGuard aplikace.',
    'Info' => 'Informace',
    'Issues' => 'Problémy',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Živě',
    'Log' => 'Záznam',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Max #připojení',
    'More' => 'Více',
    'N/A' => 'N/A',
    'Name' => 'Jméno',
    'New Configuration' => 'Nová konfigurace',
    'New Password' => 'Nové heslo',
    'New Password (confirm)' => 'Nové heslo (potvrzení)',
    'New Password and New Password (confirm) MUST match!' => 'Nové heslo a nové heslo (potvrzení) MUSÍ být stejná!',
    'No Permission(s)' => 'Žádná oprávnění',
    'No VPN profiles are available for your account.' => 'Pro váš účet nejsou dostupné žádné VPN profily.',
    'Node URL' => 'Adresa uzlu',
    'Node(s)' => 'Uzly',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Získejte nový konfigurační soubor pro použití ve Vašem VPN klientovi.',
    'Offered Ports' => 'Nabízené porty',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Udělte souhlas pouze tehdy, pokud se snažíte navázat VPN spojení s touto aplikací!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Záznam OpenVPN serveru',
    'Password' => 'Heslo',
    'Permissions' => 'Oprávnění',
    'Please sign in with your username and password.' => 'Prosím přihlašte se svým uživatelským jménem a heslem.',
    'Port' => 'Port',
    'Ports' => 'Porty',
    'Preferred Protocol' => 'Upřednostňovaný protokol',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Použití profilu',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profily',
    //'Proxy URL' => '',
    'Public Key' => 'Veřejný klíč',
    //'Refresh' => '',
    'Results' => 'Výsledky',
    'Revoke' => 'Odebrat',
    'Route(s)' => 'Trasy',
    'Search' => 'Hledat',
    'Select a profile and choose a name, e.g. "Phone".' => 'Vyberte profil a zvolte jméno, např. "Telefon".',
    'Server' => 'Server',
    'Sign In' => 'Přihlásit se',
    'Sign Out' => 'Odhlásit se',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistiky',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Datum/Čas</em> MUSÍ být v UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Pole <em>Datum/Čas</em> přijímá data ve formátu <code>Y-m-d H:i:s</code>, např. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Poskytnuté přihlašovací údaje nebyly správné.',
    'The list of applications you authorized to create a VPN connection.' => 'Seznam aplikací, které jste autorizovali k vytvoření VPN spojení.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Maximální počet současně připojených VPN klientů v konkrétním okamžiku během posledního týdne',
    'The most recent VPN connections with this account.' => 'Nejnovější VPN spojení s tímto účtem.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Počet aktuálně připojených VPN klientů a maximální možný počet připojených VPN klientů na základě dostupného IP prostoru pro tento profil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Počet jedinečných externích uživatelů připojujících se k VPN službě během posledního týdne',
    'The number of unique users connecting to the VPN service in the last week' => 'Počet jedinečných uživatelů připojujících se k VPN službě během posledního týdne',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabulka níže zobrazuje použití VPN na profil během posledního týdne.',
    'There are no results matching your criteria.' => 'Nejsou zde žádné výsledky odpovídající vašim kritériím.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Tento server používá externí autentizační zdroj. Smazání dat účtu nezabrání uživateli v opětovné autentizaci!',
    'This user does not have any active configurations.' => 'Tento uživatel nemá žádné aktivní konfigurace.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Tento uživatel nemá žádná připojení.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Aby se předešlo zákeřným aplikacím, které by tajně navazovaly VPN spojení za Vás, musíte tuto aplikaci nejprve explicitně schválit.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Použijte aplikaci WireGuard na Vašem mobilním zařízení k naskenování tohoto QR kódu.',
    'User ID' => 'Uživatelské ID',
    'Username' => 'Uživatelské jméno',
    'Users' => 'Uživatelé',
    'VPN Portal' => 'VPN portál',
    'Version' => 'Verze',
    'Welcome to this VPN service!' => 'Vítejte v této VPN službě!',
    'Why is this necessary?' => 'Proč je toto nutné?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfigurace',
    'You can download the detailed VPN usage statistics below.' => 'Podrobné statistiky použití VPN si můžete stáhnout níže.',
    'You cannot manage your own user account.' => 'Nemůžete spravovat svůj vlastní uživatelský účet.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Dosáhli jste maximálního počtu povolených aktivních VPN konfigurací. Nejprve některé konfigurace smažte.',
    'Your account does not have access to any VPN profile.' => 'Váš účet nemá přístup k žádnému VPN profilu.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Vaše nová konfigurace vyprší %expiryDate%. Po vypršení se vraťte na tuto stránku pro získání nové konfigurace!',
];
