<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'Verbindungen im 5-Minuten-Takt',
    //'#Unique Guest Users' => '',
    '#Unique Users' => 'Eindeutige Nutzende',
    '#Unique users and max #connections per day' => 'Eindeutige Nutzende und maximale Anzahl von Verbindungen pro Tag',
    'ACL Permission List' => 'ACL Berechtigungsliste',
    'Account' => 'Benutzerkonto',
    'Active' => 'Aktiv',
    'Active Configurations' => 'Aktive Einstellungen',
    //'Additional Credential' => '',
    'Aggregated' => 'Aggregiert',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => 'Eine Anwendung versucht eine VPN-Verbindung aufzubauen.',
    'An error occurred.' => 'Ein Fehler ist aufgetreten.',
    'Application Usage' => 'Anwendungsnutzung',
    'Approve' => 'Genehmigen',
    'Approve Application' => 'Genehmige Anwendung',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Autorisierte Anwendungen',
    'Authorized On' => 'Autorisiert am',
    'Available Profiles' => 'Verfügbare Profile',
    'Block LAN' => 'LAN blockieren',
    'CA' => 'Zertifizierungsstelle',
    'CPU Usage:' => 'Prozessor-Auslastung',
    'Change Password' => 'Passwort ändern',
    'Configurations' => 'Einstellungen',
    'Confirm' => 'Bestätigen',
    'Connected' => 'Verbunden',
    'Connections' => 'Verbindungen',
    'Created On' => 'Generiert am',
    'Current Password' => 'Derzeitiges Passwort',
    'Current Password not correct!' => 'Derzeitiges Passwort ist nicht korrekt!',
    'Currently there are no clients connected to this profile.' => 'Derzeit sind keine Clients über dieses Profil verbunden.',
    'DNS Search Domain(s)' => 'DNS Suche Domain(s)',
    'DNS Server(s)' => 'DNS Server',
    'Danger Zone' => 'Gefahrenbereich',
    //'Database' => '',
    'Date/Time' => 'Datum/Zeit',
    'Default Gateway' => 'Standard Gateway ',
    'Delete' => 'Löschen',
    'Delete Account' => 'Lösche Benutzerkonto',
    'Delete Account Data' => 'Lösche Benutzerkonto Daten',
    'Disable Account' => 'Deaktiviere Benutzerkonto',
    'Disabled' => 'Deaktiviert',
    'Disconnected' => 'Getrennt',
    'Distribution of unique users over the VPN applications.' => 'Verteilung eindeutiger Benutzer über die VPN-Anwendungen.',
    'Download' => 'Herunterladen',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Herunterladen der VPN Konfigurationen ist nicht möglich. Bitte nutze eine VPN Anwendung',
    //'Driver' => '',
    'Enable Account' => 'Aktiviere Benutzeraccount',
    'Error' => 'Fehler',
    'Excluded Route(s)' => 'Ausgenommene Routen',
    'Expires On' => 'Läuft ab am',
    'Export (CSV)' => 'Exportiere (CVS)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Suche die Benutzerkennung, die zu einem bestimmten Zeitpunkt eine IPv4- oder IPv6-Adresse verwendet hat.',
    'Fingerprint' => 'Fingerprint',
    'Here you can change the password for your account.' => 'Hier kannst Du dein Passwort ändern.',
    'Home' => 'Home',
    'Hostname' => 'Rechnername',
    'IP Address' => 'IP-Adresse',
    'IPs' => 'IP\'s',
    'IPv4 Prefix' => 'IPv4 Präfix',
    'IPv6 Prefix' => 'IPv6 Präfix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importieren oder kopieren Sie diese Konfiguration in Ihre WireGuard Anwendung.',
    'Info' => 'Info',
    'Issues' => 'Probleme',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Live',
    'Log' => 'Log',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Maximale Anzahl der Verbindungen',
    'More' => 'Mehr',
    'N/A' => 'Nicht verfügbar',
    'Name' => 'Name',
    'New Configuration' => 'Neue Konfiguration',
    'New Password' => 'Neues Passwort',
    'New Password (confirm)' => 'Wiederhole neues Passwort',
    'New Password and New Password (confirm) MUST match!' => 'Neues Passwort und das wiederholte Passwort MÜSSEN übereinstimmen!',
    'No Permission(s)' => 'Keine Berechtigung(en)',
    'No VPN profiles are available for your account.' => 'Für dein Benutzerkonto sind keine VPN-Profile verfügbar.',
    'Node URL' => 'Node URL',
    'Node(s)' => 'Node(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Beziehe eine neue VPN Konfiguration zur Verwendung in deinem VPN-Client.',
    'Offered Ports' => 'Vorgeschlagene Ports',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Erlaube dies nur, wenn Du versuchst eine VPN-Verbindung mit dieser Anwendung herzustellen.',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVpn Server Logdatei',
    'Password' => 'Passwort',
    'Permissions' => 'Berechtigungen',
    'Please sign in with your username and password.' => 'Bitte melde dich mit Benutzername und Passwort an.',
    'Port' => 'Port',
    'Ports' => 'Ports',
    'Preferred Protocol' => 'Bevorzugtes Protokoll',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Standardnutzung',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(e)',
    //'Proxy URL' => '',
    'Public Key' => 'Öffentlicher Schlüssel',
    //'Refresh' => '',
    'Results' => 'Ergebnisse',
    'Revoke' => 'Widerrufen',
    'Route(s)' => 'Route(n)',
    'Search' => 'Suchen',
    'Select a profile and choose a name, e.g. "Phone".' => 'Wähle ein Profil und gib ihm einen Namen, z.B. "Smartphone"',
    'Server' => 'Server',
    'Sign In' => 'Anmelden',
    'Sign Out' => 'Abmelden',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistiken',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => 'Die Angaben <em>Date/Time</em> MÜSSEN in UTC angegeben werden.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Das <em>Datum/Zeit</em>-Feld erlaubt nur folgendes Format: <code>Y-m-d H:i:s</code>, Bsp. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Die eingegebenen Daten sind ungültig.',
    'The list of applications you authorized to create a VPN connection.' => 'Liste der Anwendungen, welche Du erlaubst um eine VPN-Verbindung herzustellen.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Die maximale Anzahl der gleichzeitig verbundenen VPN Clients zu einem bestimmten Zeitpunkt in der letzten Woche.',
    'The most recent VPN connections with this account.' => 'Die letzte aktive VPN Verbindungen mit diesem Beutzerkonto.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Die Anzahl der Benutzenden, die sich in der letzten Woche mit dem VPN Dienst verbunden haben.',
    'The table below shows the per profile VPN usage over the last week.' => 'Die folgende Tabelle zeigt die VPN Nutzung pro Profil der letzten Woche an.',
    'There are no results matching your criteria.' => 'Keine Ergebnisse zu diesem Kriterium.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Dieser Server greift auf eine externe Authentifizierung zurück. Den Benutzeraccount zu löschen verhindert nicht, dass sich die Benutzer einen neuen Zugang erstellen können!',
    'This user does not have any active configurations.' => 'Dieser Nutzende hat keine aktive Konfiguration',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Dieser Nutzende hat aktuell keine Verbindungen etabliert',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Um Schadsoftware davon abzuhalten automatisiert eine VPN-Verbindung herzustellen, musst Du dies explizit dieser Anwendung genehmigen.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Nutze die WireGuard Anwendung auf deinem mobilen Endgerät um den QR Code einzuscannen',
    'User ID' => 'Benutzerkennung',
    'Username' => 'Benutzername',
    'Users' => 'Benutzer',
    'VPN Portal' => 'VPN-Portal',
    'Version' => 'Version',
    'Welcome to this VPN service!' => 'Willkommen zu diesem VPN-Dienst!',
    'Why is this necessary?' => 'Warum ist das nötig?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard Konfiguration',
    'You can download the detailed VPN usage statistics below.' => 'Du kannst die detaillierte VPN Nutzungsstatistik unten herunterladen.',
    'You cannot manage your own user account.' => 'Du kannst keine Änderungen an deinem Benutzerkonto durchführen.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Du hast die maximale Anzahl der zulässigen aktiven VPN Profile erreicht. Um ein neues zu erstellen, lösche zuerst ein ungenutztes Profil.',
    'Your account does not have access to any VPN profile.' => 'Du hast noch kein VPN Profil mit deinem Benutzeraccount generiert.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Deine neue Konfiguration wird am %expiryDate% ungültig. Erstelle erneut eine Konfiguration, sobald die aktuelle ungültig ist.',
];
