<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '#Forbindelser i 5 minutters intervaller',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Unike brukere',
    '#Unique users and max #connections per day' => '#Unike brukere og maks #forbindelser per dag',
    'ACL Permission List' => 'ACL tillatt liste',
    'Account' => 'Konto',
    'Active' => 'Aktiv',
    'Active Configurations' => 'Aktive konfigurasjoner',
    //'Additional Credential' => '',
    'Aggregated' => 'Aggregert',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => 'En applikasjon prøver å koble til VPN.',
    'An error occurred.' => 'Noe har gått galt.',
    'Application Usage' => 'Applikasjonsbruk',
    'Approve' => 'Tillat',
    'Approve Application' => 'Tillat applikasjon',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Autoriserte applikasjoner',
    'Authorized On' => 'Autorisert den',
    'Available Profiles' => 'Tilgjengelige profiler',
    'Block LAN' => 'Blokker LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU bruk',
    'Change Password' => 'Passord',
    'Configurations' => 'Konfigurasjon',
    'Confirm' => 'Bekreft',
    'Connected' => 'Tilkoblet',
    'Connections' => 'Tilkoblinger',
    'Created On' => 'Opprettet den',
    'Current Password' => 'Nåværende passord',
    'Current Password not correct!' => 'Nåværende passord stemmer ikke!',
    'Currently there are no clients connected to this profile.' => 'Det er ingen klienter koblet til denne profilen',
    'DNS Search Domain(s)' => 'DNS søke domene(r)',
    'DNS Server(s)' => 'DNS tjenere',
    'Danger Zone' => 'Farlig sone',
    //'Database' => '',
    'Date/Time' => 'Dato/Tid',
    'Default Gateway' => 'Default Gateway',
    'Delete' => 'Slett',
    'Delete Account' => 'Slett konto',
    'Delete Account Data' => 'Slett kontodata',
    'Disable Account' => 'Deaktiver konto',
    'Disabled' => 'Sperret',
    'Disconnected' => 'Frakoblet',
    'Distribution of unique users over the VPN applications.' => 'Distribusjon av unike brukere per VPN-applikasjon.',
    'Download' => 'Nedlasting',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Nedlasting av VPN konfigurasjon er ikke tillatt. Vennligst bruk en VPN applikasjon',
    //'Driver' => '',
    'Enable Account' => 'Aktiver konto',
    'Error' => 'Feil',
    'Excluded Route(s)' => 'Ekskluderte ruter',
    'Expires On' => 'Utløper den',
    'Export (CSV)' => 'Eksporter (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Finn brukeridentifikator knyttet til IPv4- eller IPv6-adressen på et bestemt tidspunkt.',
    'Fingerprint' => 'Fingeravtrykk',
    'Here you can change the password for your account.' => 'Her kan du endre passordet til kontoen din.',
    'Home' => 'Hjem',
    'Hostname' => 'Vertsnavn',
    'IP Address' => 'IP-adresse',
    'IPs' => 'IPer',
    'IPv4 Prefix' => 'IPv4 Prefiks',
    'IPv6 Prefix' => 'IPv6 Prefiks',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importer eller kopi & lim inn konfigurasjonen i din WireGuard applikasjon.',
    'Info' => 'Informasjon',
    'Issues' => 'Problemer',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Sanntid',
    'Log' => 'Logg',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Maksimum #Forbindelser',
    'More' => 'Mer',
    'N/A' => 'N/A',
    'Name' => 'Navn',
    'New Configuration' => 'Ny konfigurasjon',
    'New Password' => 'Nytt Passord',
    'New Password (confirm)' => 'Nytt Passord (bekreft)',
    'New Password and New Password (confirm) MUST match!' => 'Nytt Passord og Nytt Passord (bekreft) MÅ være det samme!',
    'No Permission(s)' => 'Ingen tilgang(er)',
    'No VPN profiles are available for your account.' => 'Ingen VPN-profiler er tilgjengelig.',
    'Node URL' => 'Node URL',
    'Node(s)' => 'Node(r)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Hent ny VPN konfigurasjon til VPN klient',
    'Offered Ports' => 'Mulige porter',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Kun tillat dette dersom du ønsker å koble til VPN med denne applikasjonen!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN tjener logg',
    'Password' => 'Passord',
    'Permissions' => 'Tillatelser',
    'Please sign in with your username and password.' => 'Logg inn med ditt brukernavn og passord.',
    'Port' => 'Port',
    'Ports' => 'Porter',
    'Preferred Protocol' => 'Foretrukket protokoll',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Profil bruk',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(er)',
    //'Proxy URL' => '',
    'Public Key' => 'Offentlig nøkkel',
    //'Refresh' => '',
    'Results' => 'Resultater',
    'Revoke' => 'Tilbakekall',
    'Route(s)' => 'Rute(r)',
    'Search' => 'Søk',
    'Select a profile and choose a name, e.g. "Phone".' => 'Velg et profil og velg et navn, f.eks "Telefon".',
    'Server' => 'Tjener',
    'Sign In' => 'Logg inn',
    'Sign Out' => 'Logg ut',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistikk',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Dato/Tid</em>-feltet MÅ være UTC',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '<em>Dato/Tid</em>-feltet tar datoformat <code>Y-m-d H:i:s</code>, f.eks. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Innloggingsdetaljene er ikke riktige.',
    'The list of applications you authorized to create a VPN connection.' => 'Liste over applikasjoner du har tillatt å opprette en VPN-tilkobling.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Maksimalt antall samtidig oppkoblede VPN klienter i løpet av den siste uken',
    'The most recent VPN connections with this account.' => 'De siste VPN oppkoblingene med denne kontoen',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Antall unike brukere koblet til denne VPN tjenesten siste uke',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabellen under viser bruk per profil siste uke',
    'There are no results matching your criteria.' => 'Ingen treff på dette søket.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Denne tjeneren bruker en ekstern autentiseringskilde. Sletting av data tilknyttet konto hindrer ikke bruker å logge på (igjen)!',
    'This user does not have any active configurations.' => 'Bruker har ingen aktiv konfigurasjon',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Bruker har ingen aktive forbindelser',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'For å forhindre at onde applikasjoner kan koble til VPN på din vegne i hemmelighet, må du eksplisitt tillate denne applikasjonen først.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Skann denne QR-koden med WireGuard app på mobilen',
    'User ID' => 'Bruker-ID',
    'Username' => 'Brukernavn',
    'Users' => 'Brukere',
    'VPN Portal' => 'VPN-Portal',
    'Version' => 'Versjon',
    'Welcome to this VPN service!' => 'Velkommen til VPN-tjenesten!',
    'Why is this necessary?' => 'Hvor er dette nødvendig?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfigurasjon',
    'You can download the detailed VPN usage statistics below.' => 'Her kan du laste ned detaljert VPN bruks statistikk.',
    'You cannot manage your own user account.' => 'Du kan ikke administrere din egen brukerkonto.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Du har maksimalt antall tillatte VPN konfigurasjoner. Du må slette noen for å opprette nye.',
    'Your account does not have access to any VPN profile.' => 'Din konto har ikke tilgang til en VPN profil.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Din nye konfigurasjon er gyldig til %expiryDate%. Da kan du gå tilbake til denne siden for å opprette en ny.',
];
