<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Aktyvūs (maks. #Galimi) prisijungimai',
    '#Connections in 5 minute intervals' => '#Prisijungimai 5 minučių intervalais',
    '#Unique Guest Users' => '#Unikalųs svečių naudotojai',
    '#Unique Users' => '#Unikalųs naudotojai',
    '#Unique users and max #connections per day' => '#Unikalūs naudotojai ir maksimalus #ryšių skaičius per dieną',
    'ACL Permission List' => 'ACL teisių sąrašas',
    'Account' => 'Paskyra',
    'Active' => 'Aktyvus',
    'Active Configurations' => 'Aktyvi konfigūracija',
    //'Additional Credential' => '',
    'Aggregated' => 'Agreguota',
    'All' => 'Visi',
    'An application attempts to establish a VPN connection.' => 'Programa bando užmegzti VPN ryšį.',
    'An error occurred.' => 'Įvyko klaida.',
    'Application Usage' => 'Aplikacijos naudojimas',
    'Approve' => 'Patvirtinti',
    'Approve Application' => 'Aplikacijos patvirtinimas',
    'Authentication Data' => 'Autentificavimo data',
    'Authorized Applications' => 'Autorizuotos aplikacijos',
    'Authorized On' => 'Autorizuota',
    'Available Profiles' => 'Prieinami profiliai',
    'Block LAN' => 'Blokuojami LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU naudojimas',
    'Change Password' => 'Slaptažodžio keitimas',
    'Configurations' => 'Konfigūracijos',
    'Confirm' => 'Patvirtinti',
    'Connected' => 'Prisijungta',
    'Connections' => 'Prisijungimai',
    'Created On' => 'Sukurta',
    'Current Password' => 'Esamas slaptažodis',
    'Current Password not correct!' => 'Esamas slaptažodis neteisingas!',
    'Currently there are no clients connected to this profile.' => 'Šiuo metu nėra klientų prisijungusių prie šio profilio',
    'DNS Search Domain(s)' => 'DNS ieškomi domenai',
    'DNS Server(s)' => 'DNS serveriai',
    'Danger Zone' => 'Pavojinga zona',
    //'Database' => '',
    'Date/Time' => 'Data/Laikas',
    'Default Gateway' => 'Pagrindinis maršrutas',
    'Delete' => 'Pašalinti',
    'Delete Account' => 'Pašalinti paskyrą',
    'Delete Account Data' => 'Pašalinti paskyros duomenis',
    'Disable Account' => 'Deaktyvuoti paskyrą',
    'Disabled' => 'Deaktyvuoti',
    'Disconnected' => 'Atjungti',
    //'Distribution of unique users over the VPN applications.' => '',
    'Download' => 'Atsisiųsti',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Parsisiųsti VPN konfigūracijos negalima. Prašome naudoti VPN aplikaciją',
    //'Driver' => '',
    'Enable Account' => 'Aktyvuoti paskyrą',
    'Error' => 'Klaida',
    'Excluded Route(s)' => 'Maršrutų išimtys',
    'Expires On' => 'Baigiasi galioti',
    'Export (CSV)' => 'Eksportuoti (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    //'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => '',
    'Fingerprint' => 'Piršto atspaudas',
    //'Here you can change the password for your account.' => '',
    'Home' => 'Pradžia',
    'Hostname' => 'Serverio pavadinimas',
    'IP Address' => 'IP numeris',
    'IPs' => 'IP adresai',
    'IPv4 Prefix' => 'IPv4 Prefiksas',
    'IPv6 Prefix' => 'IPv6 Prefiksas',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importuokite arba nukopijuokite / įklijuokite šią konfigūraciją į savo „WireGuard“ programą.',
    'Info' => 'Informacija',
    'Issues' => 'Problemos',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Gyvas',
    'Log' => 'Įvykių žurnalas',
    'MTU' => 'MTU',
    //'Maintenance' => '',
    'Max #Connections' => 'Max #Connection',
    'More' => 'Daugiau',
    'N/A' => 'N/A',
    'Name' => 'Pavadinimas',
    'New Configuration' => 'Nauja konfigūracija',
    'New Password' => 'Naujas slaptažodis',
    'New Password (confirm)' => 'Naujas slaptažodis (pakartotinai)',
    'New Password and New Password (confirm) MUST match!' => 'Naujas slaptažodis ir pakartotinai įvestas slaptažodis PRIVALP sitapti!',
    'No Permission(s)' => 'Nėra teisių',
    'No VPN profiles are available for your account.' => 'Jūsų paskyrai nėra prieinamų VPN profilių',
    'Node URL' => 'Mazgo URL',
    'Node(s)' => 'Mazgas(ai)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Gaukite naują VPN konfigūracijos failą, kurį naudosite savo VPN kliente.',
    'Offered Ports' => 'Siūlomi prievadai',
    'Offline' => 'Neprisijungęs',
    'Online' => 'Prisijungęs',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Patvirtinkite tai tik tada, kai bandote užmegzti VPN ryšį su šia programa!',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Pageidaujamas TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Pageidaujamas UDP)',
    'OpenVPN Server Log' => 'OpenVPN serverio žurnalas',
    'Password' => 'Slaptažodis',
    'Permissions' => 'Teisės',
    'Please sign in with your username and password.' => 'Prisijunkite naudodami savo vartotojo vardą ir slaptažodį.',
    'Port' => 'Prievadas',
    'Ports' => 'Prievadai',
    'Preferred Protocol' => 'Pageidaujamas protokolas',
    'Profile' => 'Profilis',
    'Profile ID' => 'Profilio ID',
    'Profile Usage' => 'Profilio naudojimas',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profiliai',
    //'Proxy URL' => '',
    'Public Key' => 'Viešas raktas',
    'Refresh' => 'Atnaujinti',
    'Results' => 'Rezultatai',
    'Revoke' => 'Atšaukti',
    'Route(s)' => 'Keliai',
    'Search' => 'Paieška',
    'Select a profile and choose a name, e.g. "Phone".' => 'Pasirinkite profilį ir pasirinkite pavadinimą, pvz. "Telefonas".',
    'Server' => 'Serveris',
    'Sign In' => 'Prisijungti',
    'Sign Out' => 'Atsijungti',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistika',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Data/Laikas</em> PRIVALO būti UTC formatu.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => '<em>Data / laikas</em> priimamos <code>Y-m-d H:i:s</code> formato datos, pvz., <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Jūsų pateikti prisijungimo duomenys buvo neteisingi.',
    'The list of applications you authorized to create a VPN connection.' => 'Programų, kurioms suteiktos teisės užmegsti VPN ryšį, sąrašas.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Didžiausias vienu metu prisijungusių VPN klientų skaičius konkrečiu laiko momentu per paskutinę savaitę',
    'The most recent VPN connections with this account.' => 'Naujausi VPN ryšiai su šia paskyra.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Šiuo metu prijungtų VPN klientų skaičius ir didžiausias galimas prijungtų VPN klientų skaičius, atsižvelgiant į laisvą šio profilio IP erdvę.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Unikalių vartotojų, prisijungusių prie VPN paslaugų, skaičius per pastarąją savaitę',
    'The number of unique users connecting to the VPN service in the last week' => 'Unikalių vartotojų, prisijungusių prie VPN paslaugos, skaičius per pastarąją savaitę',
    'The table below shows the per profile VPN usage over the last week.' => 'Žemiau esančioje lentelėje parodytas VPN naudojimas profilyje per paskutinę savaitę.',
    'There are no results matching your criteria.' => 'Nėra rezultatų, atitinkančių jūsų kriterijus.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Šis serveris naudoja išorinį autentifikavimo šaltinį. Paskyros duomenų ištrynimas nesutrukdys vartotojui (vėl) autentifikuotis!',
    'This user does not have any active configurations.' => 'Šis vartotojas neturi jokių aktyvių ryšių.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Šis vartotojas neturi jokių ryšių.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Norėdami užkirsti kelią kenkėjiškoms programoms slaptai užmegzti VPN ryšį jūsų vardu, pirmiausia turite patvirtinti šią programą.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Norėdami nuskaityti šį QR kodą, naudokite „WireGuard“ programą savo mobiliajame įrenginyje.',
    'User ID' => 'Naudotojo ID',
    'Username' => 'Naudotojoas',
    'Users' => 'Naudotojai',
    'VPN Portal' => 'VPN portalas',
    'Version' => 'Versija',
    'Welcome to this VPN service!' => 'Sveiki atvykę į šią VPN paslaugą!',
    'Why is this necessary?' => 'Kodėl tai būtina?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfigūracija',
    'You can download the detailed VPN usage statistics below.' => 'Galite atsisiųsti išsamią VPN naudojimo statistiką.',
    'You cannot manage your own user account.' => 'Jūs negalite valdyti savo paties naudotojo paskyros.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Pasiekėte didžiausią leistiną aktyvių VPN konfigūracijų skaičių. Pirmiausia ištrinkite kurias nors.',
    'Your account does not have access to any VPN profile.' => 'Jūsų paskyra neturi prieigos prie jokio VPN profilio.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Naujos konfigūracijos galiojimo laikas baigsis %expiryDate%. Grįžkite čia ir gaukite naują konfigūraciją pasibaigus galiojimo laikui!',
];
