<?php

declare(strict_types=1);

/*
 * Copyright (c) 2023-2024 François Kooman <fkooman@tuxed.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

namespace fkooman\Radius;

class MessageAuthenticator
{
    public static function calculate(RadiusPacket $radiusPacket, string $sharedSecret): string
    {
        $radiusPacketCopy = clone $radiusPacket;
        $radiusPacketCopy->attributeCollection()->set('Message-Authenticator', str_repeat("\x00", 16));

        return Utils::calculateHmac($radiusPacketCopy->toBytes(), $sharedSecret);
    }

    public static function verify(RadiusPacket $radiusPacket, string $sharedSecret, ?string $requestAuthenticator = null): ?bool
    {
        if (null === $messageAuthenticator = $radiusPacket->attributeCollection()->getOne('Message-Authenticator')) {
            return null;
        }

        $radiusPacketCopy = clone $radiusPacket;
        $radiusPacketCopy->attributeCollection()->set('Message-Authenticator', str_repeat("\x00", 16));
        if (null !== $requestAuthenticator) {
            // only when verifying a *response* do we need to set the
            // Authenticator field to the one of the request
            $radiusPacketCopy->setPacketAuthenticator($requestAuthenticator);
        }

        return hash_equals(
            Utils::calculateHmac($radiusPacketCopy->toBytes(), $sharedSecret),
            Utils::requireLength($messageAuthenticator, 16)
        );
    }
}
