<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitef775a4181e13dbbefc529830e3acaad
{
    public static $prefixLengthsPsr4 = array (
        'f' => 
        array (
            'fkooman\\SeCookie\\' => 17,
            'fkooman\\Radius\\' => 15,
            'fkooman\\OAuth\\Server\\' => 21,
        ),
        'V' => 
        array (
            'Vpn\\Portal\\' => 11,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'fkooman\\SeCookie\\' => 
        array (
            0 => __DIR__ . '/..' . '/fkooman/secookie/src',
        ),
        'fkooman\\Radius\\' => 
        array (
            0 => __DIR__ . '/..' . '/fkooman/radius/src',
        ),
        'fkooman\\OAuth\\Server\\' => 
        array (
            0 => __DIR__ . '/..' . '/fkooman/oauth2-server/src',
        ),
        'Vpn\\Portal\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitef775a4181e13dbbefc529830e3acaad::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitef775a4181e13dbbefc529830e3acaad::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitef775a4181e13dbbefc529830e3acaad::$classMap;

        }, null, ClassLoader::class);
    }
}
