<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'fkooman\\SeCookie\\' => array($vendorDir . '/fkooman/secookie/src'),
    'fkooman\\Radius\\' => array($vendorDir . '/fkooman/radius/src'),
    'fkooman\\OAuth\\Server\\' => array($vendorDir . '/fkooman/oauth2-server/src'),
    'Vpn\\Portal\\' => array($baseDir . '/src'),
);
