<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    //'#Connections in 5 minute intervals' => '',
    //'#Unique Guest Users' => '',
    //'#Unique Users' => '',
    //'#Unique users and max #connections per day' => '',
    //'ACL Permission List' => '',
    'Account' => 'Konto',
    'Active' => 'Aktywny',
    //'Active Configurations' => '',
    //'Additional Credential' => '',
    //'Aggregated' => '',
    //'All' => '',
    'An application attempts to establish a VPN connection.' => 'Aplikacja próbuje zestawić połączenie VPN.',
    'An error occurred.' => 'Wystąpił błąd.',
    'Application Usage' => 'Wykorzystanie aplikacji',
    'Approve' => 'Zaakceptuj',
    'Approve Application' => 'Zaakceptuj aplikację',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Zautoryzowane aplikacje',
    //'Authorized On' => '',
    //'Available Profiles' => '',
    //'Block LAN' => '',
    //'CA' => '',
    //'CPU Usage:' => '',
    'Change Password' => 'Zmień hasło',
    'Configurations' => 'Konfiguracje',
    'Confirm' => 'Potwierdź',
    'Connected' => 'Połączony',
    'Connections' => 'Połączenia',
    //'Created On' => '',
    'Current Password' => 'Aktualne hasło',
    'Current Password not correct!' => 'Aktualne hasło jest nieprawidłowe!',
    //'Currently there are no clients connected to this profile.' => '',
    //'DNS Search Domain(s)' => '',
    //'DNS Server(s)' => '',
    //'Danger Zone' => '',
    //'Database' => '',
    'Date/Time' => 'Data/Czas',
    //'Default Gateway' => '',
    'Delete' => 'Skasuj',
    //'Delete Account' => '',
    //'Delete Account Data' => '',
    //'Disable Account' => '',
    'Disabled' => 'Zablokowany',
    'Disconnected' => 'Rozłączono',
    'Distribution of unique users over the VPN applications.' => 'Rozkład statystyczny aplikacji używanych przez użytkowników',
    //'Download' => '',
    //'Downloading VPN configurations is not allowed. Please use a VPN application.' => '',
    //'Driver' => '',
    //'Enable Account' => '',
    'Error' => 'Błąd',
    //'Excluded Route(s)' => '',
    //'Expires On' => '',
    //'Export (CSV)' => '',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Wyszukiwanie użytkownika, który używał adresu IPv4 lub IPv6 w danym momencie.',
    //'Fingerprint' => '',
    'Here you can change the password for your account.' => 'Poniższy formularz umożliwia zmianę hasła.',
    'Home' => 'Strona główna',
    //'Hostname' => '',
    'IP Address' => 'Adres IP',
    'IPs' => 'IP',
    //'IPv4 Prefix' => '',
    //'IPv6 Prefix' => '',
    //'Import or copy/paste this configuration to your WireGuard application.' => '',
    'Info' => 'Informacje',
    //'Issues' => '',
    //'Keepalive' => '',
    //'Last Used' => '',
    //'Live' => '',
    'Log' => 'Log',
    //'MTU' => '',
    //'Maintenance' => '',
    //'Max #Connections' => '',
    //'More' => '',
    'N/A' => 'brak',
    'Name' => 'Nazwa',
    //'New Configuration' => '',
    'New Password' => 'Nowe hasło',
    'New Password (confirm)' => 'Nowe hasło (powtórnie)',
    'New Password and New Password (confirm) MUST match!' => 'Podano dwa różne nowe hasła!',
    //'No Permission(s)' => '',
    'No VPN profiles are available for your account.' => 'Żadne profile VPN nie są dostępne dla Twojego konta.',
    //'Node URL' => '',
    //'Node(s)' => '',
    //'OAuth' => '',
    //'Obtain a new VPN configuration file for use in your VPN client.' => '',
    //'Offered Ports' => '',
    //'Offline' => '',
    //'Online' => '',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Zaakceptuj tylko wtedy, gdy jesteś pewien, że zestawiasz połączenie VPN za pomocą tej aplikacji!',
    //'OpenVPN' => '',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    //'OpenVPN Server Log' => '',
    'Password' => 'Hasło',
    //'Permissions' => '',
    'Please sign in with your username and password.' => 'Proszę zalogować się za pomocą nazwy użytkownika i hasła.',
    //'Port' => '',
    //'Ports' => '',
    //'Preferred Protocol' => '',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    //'Profile Usage' => '',
    //'Profile no longer available with your current permissions.' => '',
    //'Profile(s)' => '',
    //'Proxy URL' => '',
    //'Public Key' => '',
    //'Refresh' => '',
    'Results' => 'Wyniki',
    'Revoke' => 'Unieważnij',
    //'Route(s)' => '',
    'Search' => 'Szukaj',
    'Select a profile and choose a name, e.g. "Phone".' => 'Wybierz profil i ustal nazwę, np. "Telefon".',
    //'Server' => '',
    'Sign In' => 'Logowanie',
    'Sign Out' => 'Wyloguj',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statystyki',
    //'TCP' => '',
    //'The <em>Date/Time</em> MUST be in UTC.' => '',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Pole daty akceptuje daty w formacie <code>Y-m-d H:i:s</code>, np. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Dane uwierzytelniające są nieprawidłowe.',
    'The list of applications you authorized to create a VPN connection.' => 'Lista aplikacji, które autoryzowałeś do zestawienia połączenia VPN.',
    //'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => '',
    //'The most recent VPN connections with this account.' => '',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    //'The number of unique users connecting to the VPN service in the last week' => '',
    //'The table below shows the per profile VPN usage over the last week.' => '',
    'There are no results matching your criteria.' => 'Brak wyników wyszukiwania.',
    //'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => '',
    //'This user does not have any active configurations.' => '',
    //'This user does not have any authorized applications.' => '',
    //'This user does not have any connections.' => '',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Aby uniemożliwić złośliwym aplikacjom niepostrzeżone zestawianie połączeń VPN, musisz najpierw wprost zaakceptować aplikację.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    //'Use the WireGuard app on your mobile device to scan this QR code.' => '',
    'User ID' => 'Użytkownik',
    'Username' => 'Nazwa użytkownika',
    'Users' => 'Użytkownicy',
    'VPN Portal' => 'Portal VPN',
    //'Version' => '',
    'Welcome to this VPN service!' => 'Witamy w usłudze VPN!',
    'Why is this necessary?' => 'Dlaczego jest to konieczne?',
    //'WireGuard' => '',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    //'WireGuard Configuration' => '',
    //'You can download the detailed VPN usage statistics below.' => '',
    'You cannot manage your own user account.' => 'Nie możesz zarządzać swoim kontem.',
    //'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => '',
    //'Your account does not have access to any VPN profile.' => '',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Twoja konfiguracja ulegnie przeterminowaniu %expiryDate%. Pobierz nową gdy się to stanie!',
];
