<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'Conexiuni la intervale de 5 minute',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Utilizatori unici',
    '#Unique users and max #connections per day' => '#Utilizatori unici și conexiunile maxime pe zi',
    'ACL Permission List' => 'Lista de permisiuni (ACL)',
    'Account' => 'Cont',
    'Active' => 'Activ',
    'Active Configurations' => 'Configurații active',
    //'Additional Credential' => '',
    'Aggregated' => 'Agregat',
    'All' => 'Toate',
    'An application attempts to establish a VPN connection.' => 'O aplicație încearcă să stabilească o conexiune VPN.',
    'An error occurred.' => 'A apărut o eroare.',
    'Application Usage' => 'Aplicații utilizate',
    'Approve' => 'Permite',
    'Approve Application' => 'Aprobă aplicația',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Aplicații autorizate',
    'Authorized On' => 'Autorizat pe',
    'Available Profiles' => 'Profiluri disponibile',
    'Block LAN' => 'Blocare LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Utilizare CPU:',
    'Change Password' => 'Schimbă parola',
    'Configurations' => 'Configurare',
    'Confirm' => 'Confirmă',
    'Connected' => 'Conectat',
    'Connections' => 'Conexiuni',
    'Created On' => 'Creat în',
    'Current Password' => 'Parolă curentă',
    'Current Password not correct!' => 'Parola curentă nu este corectă!',
    'Currently there are no clients connected to this profile.' => 'În prezent, nu există clienți conectați la acest profil.',
    'DNS Search Domain(s)' => 'Domeniu de cautare DNS',
    'DNS Server(s)' => 'Server DNS',
    'Danger Zone' => 'Zonă periculoasă',
    //'Database' => '',
    'Date/Time' => 'Dată/Oră',
    'Default Gateway' => 'Gateway implicit',
    'Delete' => 'Șterge',
    'Delete Account' => 'Șterge cont',
    'Delete Account Data' => 'Șterge datele contului',
    'Disable Account' => 'Dezactivează cont',
    'Disabled' => 'Dezactivat',
    'Disconnected' => 'Deconectat',
    'Distribution of unique users over the VPN applications.' => 'Distribuirea utilizatorilor unici pe aplicațiile VPN.',
    'Download' => 'Descarcă',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Descărcarea configurațiilor VPN nu este permisă. Vă rugăm să utilizați o aplicație VPN.',
    //'Driver' => '',
    'Enable Account' => 'Activează cont',
    'Error' => 'Eroare',
    'Excluded Route(s)' => 'Rute excluse',
    'Expires On' => 'Expiră în',
    'Export (CSV)' => 'Export (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Găsește utilizatorul care a folosit o adresă IPv4 sau IPv6 la un moment dat.',
    'Fingerprint' => 'Amprentă',
    'Here you can change the password for your account.' => 'Aici poți schimba parola contului tău.',
    'Home' => 'Acasă',
    'Hostname' => 'Hostname',
    'IP Address' => 'Adresa IP',
    'IPs' => 'IPs',
    'IPv4 Prefix' => 'Prefix IPv4',
    'IPv6 Prefix' => 'Prefix IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importați sau copiați această configurație în aplicația dumneavoastră WireGuard.',
    'Info' => 'Informații',
    'Issues' => 'Probleme',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Live',
    'Log' => 'Jurnal',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Conexiuni maxime',
    'More' => 'Mai mult',
    'N/A' => 'Indisponibil',
    'Name' => 'Nume',
    'New Configuration' => 'Configurație nouă',
    'New Password' => 'Parolă nouă',
    'New Password (confirm)' => 'Confirmă parola',
    'New Password and New Password (confirm) MUST match!' => 'Parola din câmpul "Parolă nouă" și cea din câmpul "Confirmă parola" trebuie să conincidă!',
    'No Permission(s)' => 'Fără permisiuni',
    'No VPN profiles are available for your account.' => 'Nu există profiluri VPN disponibile pentru contul tău.',
    'Node URL' => 'Adresa URL a nodului',
    'Node(s)' => 'Nod',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obțineți un nou fișier de configurare VPN pentru utilizarea acestuia în clientul VPN.',
    'Offered Ports' => 'Porturi oferite',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Aprobă acest lucru numai atunci când încerci să stabilești o conexiune VPN cu această aplicație!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN Server Log',
    'Password' => 'Parolă',
    'Permissions' => 'Permisiuni',
    'Please sign in with your username and password.' => 'Conectează-te cu numele și parola ta de utilizator.',
    'Port' => 'Port',
    'Ports' => 'Porturi',
    'Preferred Protocol' => 'Protocolul preferat',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Utilizarea profilului',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profil(e)',
    //'Proxy URL' => '',
    'Public Key' => 'Cheie publică',
    //'Refresh' => '',
    'Results' => 'Rezultate',
    'Revoke' => 'Revocă',
    'Route(s)' => 'Rute',
    'Search' => 'Caută',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selectează un profil și alege un nume, de ex: "Telefon',
    'Server' => 'Server',
    'Sign In' => 'Conectare',
    'Sign Out' => 'Deconectare',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistici',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Data/Ora</em> trebuie să fie în format UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Câmpul <em>Dată/Oră</em> acceptă date în formatul <code>Y-m-d H:i:s</code>, de exemplu: <code>2019-12-23 08:00:00</code>',
    'The credentials you provided were not correct.' => 'Numele de utilizator și/sau parola pe care le-ai introdus nu sunt corecte.',
    'The list of applications you authorized to create a VPN connection.' => 'Lista aplicațiilor pe care le-ai autorizat să creeze o conexiune VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Numărul maxim de clienți VPN conectați simultan la un moment dat în ultima săptămână',
    'The most recent VPN connections with this account.' => 'Cele mai recente conexiuni VPN cu acest cont.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Numărul de utilizatori unici care s-au conectat la serviciul VPN în ultima săptămână',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabelul de mai jos afisează utilizarea VPN pe fiecare profil în ultima săptămână.',
    'There are no results matching your criteria.' => 'Nu există rezultate care să corespundă criteriilor tale.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Acest server folosește o sursă de autentificare externă. Ștergerea datelor contului nu va împiedica utilizatorul să se autentifice (din nou)!',
    'This user does not have any active configurations.' => 'Acest utilizator nu are nicio configurație activă.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Acest utilizator nu are realizată nicio conexiune.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Pentru a preveni aplicațiile rău intenționate să stabilească în secret o conexiune VPN în numele tău, trebuie să aprobi în mod explicit această aplicație.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilizați aplicația WireGuard de pe dispozitivul dvs. mobil pentru a scana acest cod QR.',
    'User ID' => 'Cod de identificare (ID) utilizator',
    'Username' => 'Nume de utilizator',
    'Users' => 'Utilizatori',
    'VPN Portal' => 'Portalul VPN',
    'Version' => 'Versiune',
    'Welcome to this VPN service!' => 'Bine ai venit la acest serviciu de VPN!',
    'Why is this necessary?' => 'De ce este nevoie de asta?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Configurare WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Puteți descărca statisticile detaliate de utilizare de mai jos.',
    'You cannot manage your own user account.' => 'Nu poți să-ți gestionezi propriul cont.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Ați atins numărul maxim de configurații VPN active permise. Ștergeți mai întâi câteva.',
    'Your account does not have access to any VPN profile.' => 'Contul dumneavoastră nu are acces la niciun profil VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Noua configurație va expira la data de %expiryDate%. După aceasta, poți reveni aici pentru a obține o nouă configurație.',
];
