<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

namespace Vpn\Portal;

class NullLogger implements LoggerInterface
{
    public function warning(string $logMessage): void
    {
        // NOP
    }

    public function error(string $logMessage): void
    {
        // NOP
    }

    public function notice(string $logMessage): void
    {
        // NOP
    }

    public function info(string $logMessage): void
    {
        // NOP
    }

    public function debug(string $logMessage): void
    {
        // NOP
    }
}
