<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => '#Verbindings met 5 minute tussenposes',
    //'#Unique Guest Users' => '',
    '#Unique Users' => '#Unieke gebruikers',
    '#Unique users and max #connections per day' => '#Unieke gebruikers en maksimum #verbindings per dag',
    'ACL Permission List' => 'ACL-Toestemmingslys',
    'Account' => 'Rekening',
    'Active' => 'Aktief',
    'Active Configurations' => 'Aktiewe verbindings',
    //'Additional Credential' => '',
    'Aggregated' => 'Saamgevoeg',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => '\'n program probeer om \'n VPN-verbinding te vestig.',
    'An error occurred.' => '\'n fout het plaasgevind.',
    'Application Usage' => 'Program gebruik',
    'Approve' => 'Goedgekeur',
    'Approve Application' => 'Keur program goed',
    //'Authentication Data' => '',
    'Authorized Applications' => 'Goedgekeurde programme',
    'Authorized On' => 'Goedgekeur op',
    'Available Profiles' => 'Beskikbare profiele',
    'Block LAN' => 'Blokkeer LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU-gebruik:',
    'Change Password' => 'Verander wagwoord',
    'Configurations' => 'Instellings',
    'Confirm' => 'Bevestig',
    'Connected' => 'Gekoppel',
    'Connections' => 'Verbindings',
    'Created On' => 'Geskep op',
    'Current Password' => 'Huidige wagwoord',
    'Current Password not correct!' => 'Huidige wagwoord is verkeerd!',
    'Currently there are no clients connected to this profile.' => 'Daar is huidiglik geen kliente met hierdie profiel gekoppel.',
    'DNS Search Domain(s)' => 'DNS-soek Domein/e',
    'DNS Server(s)' => 'DNS-bediener',
    'Danger Zone' => 'Gevaarsone',
    //'Database' => '',
    'Date/Time' => 'Datum/Tyd',
    'Default Gateway' => 'Verstekportaal',
    'Delete' => 'Verwyder',
    'Delete Account' => 'Verwyder rekening',
    'Delete Account Data' => 'Verwyder rekening data',
    'Disable Account' => 'Deaktiveer rekening',
    'Disabled' => 'Gedeaktiveerde',
    'Disconnected' => 'Ontkoppeld',
    'Distribution of unique users over the VPN applications.' => 'Verspreiding van unieke gebruikers oor VPN-programme.',
    'Download' => 'Aflaai',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Die aflaai van VPN-instellings word nie toegelaat nie. Gebruik aseblief \'n VPN program.',
    //'Driver' => '',
    'Enable Account' => 'Aktiveer Rekening',
    'Error' => 'Fout',
    'Excluded Route(s)' => 'Uitgeslote roete(s)',
    'Expires On' => 'Verval op',
    'Export (CSV)' => 'Uitvoer (CSV)',
    //'Extend' => '',
    //'Extend the validity of the configuration until %expiryDate%' => '',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Vind die gebruiker identifiseerder wat \'n IPv4- or IPv6-adres op \'n spesifieke tydstip gebruik het.',
    'Fingerprint' => 'Vingerafdruk',
    'Here you can change the password for your account.' => 'U kan die wagwoord van U rekening hier verander.',
    'Home' => 'Tuis',
    'Hostname' => 'Gasheernaam',
    'IP Address' => 'IP-adress',
    'IPs' => 'IP\'s',
    'IPv4 Prefix' => 'IPv4-voorvoegsel',
    'IPv6 Prefix' => 'IPv6-voorvoegsel',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Voer in of kopieer/plak hierdie instellings na jou WireGuard-program.',
    'Info' => 'Inligting',
    'Issues' => 'Probleme',
    //'Keepalive' => '',
    //'Last Used' => '',
    'Live' => 'Lewendig',
    'Log' => 'Log',
    //'MTU' => '',
    //'Maintenance' => '',
    'Max #Connections' => 'Maksimum #Verbindings',
    'More' => 'Meer',
    'N/A' => 'N.v.t',
    'Name' => 'Naam',
    'New Configuration' => 'Nuwe Instelling',
    'New Password' => 'Nuwe wagwoord',
    'New Password (confirm)' => 'Nuwe wagwoord (bevestig)',
    'New Password and New Password (confirm) MUST match!' => 'Nuwe wagwoord en bevestiging moet ooreenstem!',
    'No Permission(s)' => 'Geen toestemming',
    'No VPN profiles are available for your account.' => 'Geen VPN-profiele is vir U rekening beskikbaar nie',
    'Node URL' => 'Nodus URL',
    'Node(s)' => 'Nodus(se)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Verkry \'n nuwe VPN-konfigurasielêer om in U VPN-kliënt te kan gebruik',
    'Offered Ports' => 'Aangebiede poort',
    'Offline' => 'Aflyn',
    'Online' => 'Aanlyn',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Keur hierdie goed slegs as U \'n VPN-verbinding met hierdie program probeer bevestig!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'OpenVPN bediener Log',
    'Password' => 'Wagwoord',
    'Permissions' => 'Toestemming',
    'Please sign in with your username and password.' => 'Meld aan met U gebruikersnaam en wagwoord.',
    'Port' => 'Poort',
    'Ports' => 'Poorte',
    'Preferred Protocol' => 'Voorkeur Protokol',
    'Profile' => 'Profiel',
    //'Profile ID' => '',
    'Profile Usage' => 'Profiel gebruik',
    //'Profile no longer available with your current permissions.' => '',
    'Profile(s)' => 'Profiel(e)',
    //'Proxy URL' => '',
    'Public Key' => 'Publieke Sleutel',
    //'Refresh' => '',
    'Results' => 'Uitslae',
    'Revoke' => 'Herroep',
    'Route(s)' => 'Roete(s)',
    'Search' => 'Soek',
    'Select a profile and choose a name, e.g. "Phone".' => 'Kies \'n profiel, en \'n naam b.v "Foon".',
    'Server' => 'Bediener',
    'Sign In' => 'Meld Aan',
    'Sign Out' => 'Afgemeld',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Statistieke',
    //'TCP' => '',
    'The <em>Date/Time</em> MUST be in UTC.' => 'Die <em>Datum/Tyd</em> moet in UTC wees.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Die <em>Datum/Tyd</em> veld aanvaar datums in die <code>Y-m-d H: i: s</code> formaat, b.v <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Die intekenbesonderhede wat voorsien is, is verkeerd.',
    'The list of applications you authorized to create a VPN connection.' => 'Die lys van programme wat goedgekeur is om \'n VPN-verbinding te gebruik.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Die maksimum gelyktydigverbonde VPN-klante op \'n bepaalde tydperk in die afgelope week',
    'The most recent VPN connections with this account.' => 'Die onlangse VPN-verbindings met hierdie rekening.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'Die aantal unieke gebruikers wat na die VPN-diens gekoppel het in die afgelope week',
    'The table below shows the per profile VPN usage over the last week.' => 'Die tabel hieronder toon die VPN-gebruik per profiel vir die afgelope week.',
    'There are no results matching your criteria.' => 'Daar is geen resultate wat by jou kriteria pas nie.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Hierdie bediener gebruik \'n eksterne verifikasiebron. Die gebruiker sal nie verhoed word om (weer) aan te meld as die rekening verwyder word nie!',
    'This user does not have any active configurations.' => 'Die gebruiker het nie aktiewe verstelling nie.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Die gebruiker het nie huidige verbindings nie.',
    //'To complete the sign in, you need to provide an additional credential.' => '',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'U moet eers hierdie toepassing uitdruklik goedkeur om te verhoed dat kwaadwillige VPN-verbindings in die geheim namens jou gemaak word.',
    //'Transport Protocol(s)' => '',
    //'UDP' => '',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Gebruik die WireGuard-program op U mobile toestel om hierdie QR kode te skandeer.',
    'User ID' => 'Gebruiker-ID',
    'Username' => 'Gebruikersnaam',
    'Users' => 'Gebruikers',
    'VPN Portal' => 'VPN Portaal',
    'Version' => 'Weergawe',
    'Welcome to this VPN service!' => 'Welkom by hierdie VPN-diens!',
    'Why is this necessary?' => 'Hoekom word hierdie benodig?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard-Instelling',
    'You can download the detailed VPN usage statistics below.' => 'U kan die gedetailleerde VPN-gebruikstatistieke hieronder aflaai.',
    'You cannot manage your own user account.' => 'U kan nie U eie gebruikerrekening bestuur nie.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'U het die maksimum toegelate aktiewe VPN-verbindings bereik. Skrap eers \'n paar.',
    'Your account does not have access to any VPN profile.' => 'U rekening het nie toestemming na \'n VPN-profiel nie.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'U nuwe instellings sal op %expiryDate% verval. Kom hierheen terug om \'n nuwe instelling na verstryking te kry!',
];
